@@ -4,6 +4,7 @@
 #include "Body.hpp"
 #include "Clump.hpp"
 #include "Scene.hpp"
+#include <lib/base/LoggingUtils.hpp>
 #ifdef YADE_OPENMP
 #include <omp.h>
 #endif
@@ -34,8 +35,7 @@ Body::id_t BodyContainer::insert(shared_ptr<Body> b)
 
 Body::id_t BodyContainer::insertAtId(shared_ptr<Body> b, Body::id_t candidate)
 {
-	if (not b)
-		LOG_ERROR("Inserting null body");
+	if (not b) LOG_ERROR("Inserting null body");
 	const shared_ptr<Scene>& scene = Omega::instance().getScene();
 	if (enableRedirection) {
 		dirty             = true;
@@ -77,22 +77,22 @@ const shared_ptr<Body>& BodyContainer::operator[](unsigned int id) const { retur
 
 bool BodyContainer::exists(Body::id_t id) const { return ((id >= 0) && ((size_t)id < body.size()) && ((bool)body[id])); }
 
-bool BodyContainer::erase(Body::id_t id, bool eraseClumpMembers)
+bool BodyContainer::eraseAlreadyLocked(Body::id_t id, bool eraseClumpMembers)
 { //default is false (as before)
-	if (!body[id])
-		return false;
+	if (!body[id]) return false;
+	const shared_ptr<Scene>& scene = Omega::instance().getScene();
 	if (enableRedirection) {
 		useRedirection    = true;
 		dirty             = true;
 		checkedByCollider = false;
+		erasedBodies.push_back(id);
 	} // as soon as a body is erased we switch to algorithm optimized for non-full body container
 	const shared_ptr<Body>& b = Body::byId(id);
 	if ((b) and (b->isClumpMember())) {
 		const shared_ptr<Body>  clumpBody = Body::byId(b->clumpId);
 		const shared_ptr<Clump> clump     = YADE_PTR_CAST<Clump>(clumpBody->shape);
 		Clump::del(clumpBody, b);
-		if (clump->members.size() == 0)
-			this->erase(clumpBody->id, false); //Clump has no members any more. Remove it
+		if (clump->members.size() == 0) this->eraseAlreadyLocked(clumpBody->id, false); //Clump has no members any more. Remove it
 	}
 
 	if ((b) and (b->isClump())) {
@@ -100,11 +100,11 @@ bool BodyContainer::erase(Body::id_t id, bool eraseClumpMembers)
 		const shared_ptr<Clump>&    clump   = YADE_PTR_CAST<Clump>(b->shape);
 		std::map<Body::id_t, Se3r>& members = clump->members;
 		std::vector<Body::id_t>     idsToRemove;
-		for (const auto mm : members)
+		for (const auto& mm : members)
 			idsToRemove.push_back(mm.first); // Prepare an array of ids, which need to be removed.
 		for (Body::id_t memberId : idsToRemove) {
 			if (eraseClumpMembers) {
-				this->erase(memberId, false); // erase members
+				this->eraseAlreadyLocked(memberId, false); // erase members
 			} else {
 				//when the last members is erased, the clump will be erased automatically, see above
 				Body::byId(memberId)->clumpId = Body::ID_NONE; // make members standalones
@@ -113,7 +113,7 @@ bool BodyContainer::erase(Body::id_t id, bool eraseClumpMembers)
 		body[id].reset();
 		return true;
 	}
-	const shared_ptr<Scene>& scene = Omega::instance().getScene();
+
 	for (auto it = b->intrs.begin(), end = b->intrs.end(); it != end;) { //Iterate over all body's interactions
 		Body::MapId2IntrT::iterator willBeInvalid = it;
 		++it;
@@ -124,17 +124,23 @@ bool BodyContainer::erase(Body::id_t id, bool eraseClumpMembers)
 	return true;
 }
 
-void BodyContainer::updateShortLists()
+bool BodyContainer::erase(Body::id_t id, bool eraseClumpMembers)
 {
-	if (not useRedirection) {
-#ifdef YADE_MPI
-		subdomainBodies.clear();
-#endif
-		realBodies.clear();
+	// Fix https://gitlab.com/yade-dev/trunk/-/issues/235 - wait with updating until some body removal is finished.
+	// NOTE: This is called very rarely, because it is erasing bodies. Not typical simulation occurrence.
+	//       But we still have to make sure to avoid crashes. Even those which are rare :)
+	const std::lock_guard<std::mutex> lock(drawloopmutex);
+
+	return this->eraseAlreadyLocked(id, eraseClumpMembers);
+}
+
+void BodyContainer::updateRealBodies()
+{
+	if (not enableRedirection) {
+		LOG_ONCE_WARN("updateRealBodies returns because enableRedirection is false - please report bug");
 		return;
 	}
-	if (not dirty)
-		return; //already ok
+	if (not dirty) return; //already ok
 	unsigned long size1 = realBodies.size();
 	realBodies.clear();
 	realBodies.reserve((long unsigned)(size1 * 1.3));
@@ -144,17 +150,15 @@ void BodyContainer::updateShortLists()
 	subdomainBodies.reserve((long unsigned)(size2 * 1.3));
 	const int& subdomain = Omega::instance().getScene()->subdomain;
 #endif
-	for (const auto& b : *(Omega::instance().getScene()->bodies)) {
-		if (not b)
-			continue;
+	for (const auto& b : body) {
+		if (not b) continue;
 		realBodies.push_back(b->getId());
 #ifdef YADE_MPI
-		if (b->subdomain == subdomain and not b->getIsSubdomain())
-			subdomainBodies.push_back(b->id);
+		if (b->subdomain == subdomain and not b->getIsSubdomain()) subdomainBodies.push_back(b->id);
 #endif
 	}
 	dirty = false;
 }
 
 
-} // namespace yade
\ No newline at end of file
+} // namespace yade
