@@ -55,9 +55,7 @@ void Clump::add(const shared_ptr<Body>& clumpBody, const shared_ptr<Body>& subBo
 	}
 	clumpBody->clumpId = clumpBody->id; // just to make sure
 	clumpBody->setBounded(false);       // disallow collisions with the clump itself
-	if (subBody->isStandalone()) {
-		LOG_DEBUG("Added body #" << subBody->id << " to clump #" << clumpBody->id);
-	}
+	if (subBody->isStandalone()) { LOG_DEBUG("Added body #" << subBody->id << " to clump #" << clumpBody->id); }
 }
 
 void Clump::del(const shared_ptr<Body>& clumpBody, const shared_ptr<Body>& subBody)
@@ -112,9 +110,7 @@ void Clump::updateProperties(const shared_ptr<Body>& clumpBody, unsigned int dis
 	const shared_ptr<State> state(clumpBody->state);
 	const shared_ptr<Clump> clump(YADE_PTR_CAST<Clump>(clumpBody->shape));
 
-	if (clump->members.empty()) {
-		throw std::runtime_error("Clump::updateProperties: clump has zero members.");
-	}
+	if (clump->members.empty()) { throw std::runtime_error("Clump::updateProperties: clump has zero members."); }
 	// trivial case
 	if (clump->members.size() == 1) {
 		LOG_DEBUG("Clump of size one will be treated specially.")
@@ -135,9 +131,8 @@ void Clump::updateProperties(const shared_ptr<Body>& clumpBody, unsigned int dis
 		return;
 	}
 	//check for intersections:
-	bool               intersecting = false;
-	shared_ptr<Sphere> sph(new Sphere);
-	int                Sph_Index = sph->getClassIndexStatic(); // get sphere index for checking if bodies are spheres
+	bool intersecting = false;
+	int  Sph_Index    = Sphere::getClassIndexStatic(); // get sphere index for checking if bodies are spheres
 	if (discretization > 0) {
 		for (const auto& mm : clump->members) {
 			const shared_ptr<Body> subBody1 = Body::byId(mm.first);
@@ -155,8 +150,7 @@ void Clump::updateProperties(const shared_ptr<Body>& clumpBody, unsigned int dis
 					}
 				}
 			}
-			if (intersecting)
-				break;
+			if (intersecting) break;
 		}
 	}
 	/* quantities suffixed by
@@ -190,8 +184,7 @@ void Clump::updateProperties(const shared_ptr<Body>& clumpBody, unsigned int dis
 		Real dx     = rMin / discretization; //edge length of cell
 		Real dv     = pow(dx, 3);            //volume of cell
 		long nCells = long(math::round((aabb.sizes() / dx).prod()));
-		if (nCells > 1e7)
-			LOG_WARN("Clump::updateProperties: Cell array has " << nCells << " cells. Integrate inertia may take a while ...");
+		if (nCells > 1e7) LOG_WARN("Clump::updateProperties: Cell array has " << nCells << " cells. Integrate inertia may take a while ...");
 		Vector3r x; //position vector (center) of cell
 		for (x.x() = aabb.min().x() + dx / 2.; x.x() < aabb.max().x(); x.x() += dx) {
 			for (x.y() = aabb.min().y() + dx / 2.; x.y() < aabb.max().y(); x.y() += dx) {
@@ -256,14 +249,16 @@ void Clump::updateProperties(const shared_ptr<Body>& clumpBody, unsigned int dis
 	Ic_orientG(1, 0) = Ic_orientG(0, 1);
 	Ic_orientG(2, 0) = Ic_orientG(0, 2);
 	Ic_orientG(2, 1) = Ic_orientG(1, 2); // symmetrize
-	Eigen::SelfAdjointEigenSolver<Matrix3r> decomposed(Ic_orientG);
-	const Matrix3r&                         R_g2c(decomposed.eigenvectors());
+
+	Matrix3r R_g2c;
+	matrixEigenDecomposition(Ic_orientG, R_g2c, Ic);
+
 	// has NaNs for identity matrix??
 	LOG_TRACE("R_g2c=\n" << R_g2c);
 	// set quaternion from rotation matrix
 	state->ori = Quaternionr(R_g2c);
 	state->ori.normalize();
-	state->inertia = decomposed.eigenvalues();
+	state->inertia = Ic.diagonal();
 	state->mass    = M;
 
 	// TODO: these might be calculated from members... but complicated... - someone needs that?!
@@ -354,27 +349,13 @@ void Clump::updatePropertiesNonSpherical(const shared_ptr<Body>& clumpBody, bool
 	Ic_orientG(2, 1) = Ic_orientG(1, 2); // symmetrize
 	//TRWM3MAT(Ic_orientG);
 	matrixEigenDecomposition(Ic_orientG, R_g2c, Ic);
-	/*! @bug eigendecomposition might be wrong. see http://article.gmane.org/gmane.science.physics.yade.devel/99 for message. It is worked around below, however.
-	*/
-	// has NaNs for identity matrix!
-	//TRWM3MAT(R_g2c);
 
 	// set quaternion from rotation matrix
 	state->ori = Quaternionr(R_g2c);
 	state->ori.normalize();
-	// now Ic is diagonal
 	state->inertia = Ic.diagonal();
 	state->mass    = M;
 
-
-	// this block will be removed once EigenDecomposition works for diagonal matrices
-	//#if 1
-	//	if(isnan(R_g2c(0,0))||isnan(R_g2c(0,1))||isnan(R_g2c(0,2))||isnan(R_g2c(1,0))||isnan(R_g2c(1,1))||isnan(R_g2c(1,2))||isnan(R_g2c(2,0))||isnan(R_g2c(2,1))||isnan(R_g2c(2,2))){
-	//		throw std::logic_error("Clump::updateProperties: NaNs in eigen-decomposition of inertia matrix?!");
-	//	}
-	//#endif
-	//TRWM3VEC(state->inertia);
-
 	// TODO: these might be calculated from members... but complicated... - someone needs that?!
 	state->vel = state->angVel = Vector3r::Zero();
 
