@@ -16,8 +16,7 @@ const shared_ptr<Material> Material::byLabel(const std::string& label, Scene* w_
 {
 	Scene* w = w_ ? w_ : Omega::instance().getScene().get();
 	for (const auto& m : w->materials) {
-		if (m->label == label)
-			return m;
+		if (m->label == label) return m;
 	}
 	throw std::runtime_error(("No material labeled `" + label + "'.").c_str());
 }
@@ -27,8 +26,7 @@ int Material::byLabelIndex(const std::string& label, Scene* w_)
 	Scene* w    = w_ ? w_ : Omega::instance().getScene().get();
 	size_t iMax = w->materials.size();
 	for (size_t i = 0; i < iMax; i++) {
-		if (w->materials[i]->label == label)
-			return i;
+		if (w->materials[i]->label == label) return i;
 	}
 	throw std::runtime_error(("No material labeled `" + label + "'.").c_str());
 }
