@@ -2,38 +2,37 @@
 # -*- coding: utf-8 -*-
 #
 #  untitled.py
-#  
+#
 #  Copyright 2014 Burak ER <burak@Newton>
-#  
+#
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
 #  the Free Software Foundation; either version 2 of the License, or
 #  (at your option) any later version.
-#  
+#
 #  This program is distributed in the hope that it will be useful,
 #  but WITHOUT ANY WARRANTY; without even the implied warranty of
 #  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #  GNU General Public License for more details.
-#  
+#
 #  You should have received a copy of the GNU General Public License
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 #  MA 02110-1301, USA.
-#  
-#  
+#
+#
 from past.builtins import execfile
 import sys
 
 from yadeimport import *
 
 
-
 def main():
-	
-	execfile("testDeformableBodies_pressure.py");
+
+	execfile("testDeformableBodies_pressure.py")
 
 	return 0
 
+
 if __name__ == '__main__':
 	main()
-
