@@ -7,7 +7,6 @@
 #
 # Compare output files with diff to see if the are 100% identical
 #
-
 """ THIS SCRIPT IS NOT WORKING!
 ERROR MESSAGE:
 
@@ -23,30 +22,33 @@ AttributeError: 'module' object has no attribute 'spheresToFile'
 from __future__ import print_function
 
 from os.path import exists
-sph='triax-identical-results'
-i=0; outSph=''
+sph = 'triax-identical-results'
+i = 0
+outSph = ''
 while True:
-	outSph='%s-out%02d.spheres'%(sph,i)
-	if not exists(outSph): break
-	i+=1
-inSph='%s-in.spheres'%sph
-if exists(inSph): print("Using existing initial configuration",inSph)
+	outSph = '%s-out%02d.spheres' % (sph, i)
+	if not exists(outSph):
+		break
+	i += 1
+inSph = '%s-in.spheres' % sph
+if exists(inSph):
+	print("Using existing initial configuration", inSph)
 else:
 	TriaxialTest(noFiles=True).load()
-	print("Using new initial configuration in",inSph)
+	print("Using new initial configuration in", inSph)
 	spheresToFile(inSph)
-TriaxialTest(importFilename=inSph,noFiles=True).load()
-O.usesTimeStepper=False
-O.dt=PWaveTimeStep()
+TriaxialTest(importFilename=inSph, noFiles=True).load()
+O.usesTimeStepper = False
+O.dt = PWaveTimeStep()
 #
 # uncomment this line to enable shear computation in ScGeom and then compare results with this line commented
 #
-[e for e in O.engines if e.name=='ElasticContactLaw'][0]['useShear']=True
+[e for e in O.engines if e.name == 'ElasticContactLaw'][0]['useShear'] = True
 if 1:
 	#for i in range(0,100):
 	#	#	O.save('/tmp/a.%03d.xml'%O.iter)
 	#	O.step()
-	O.run(2000,True)
+	O.run(2000, True)
 	spheresToFile(outSph)
-	print("Results saved to",outSph)
+	print("Results saved to", outSph)
 	#quit()
