@@ -15,7 +15,7 @@
 
 #pragma once
 
-#include <pkg/common/Aabb.hpp>
+#include <core/Aabb.hpp>
 #include <pkg/common/Box.hpp>
 #include <pkg/common/Facet.hpp>
 #include <pkg/common/GLDrawFunctors.hpp>
@@ -25,7 +25,7 @@ namespace yade { // Cannot have #include directive inside.
 
 class Gl1_Aabb : public GlBoundFunctor {
 public:
-	virtual void go(const shared_ptr<Bound>&, Scene*);
+	void go(const shared_ptr<Bound>&, Scene*) override;
 	RENDERS(Aabb);
 	// clang-format off
 	YADE_CLASS_BASE_DOC(Gl1_Aabb,GlBoundFunctor,"Render Axis-aligned bounding box (:yref:`Aabb`).");
@@ -36,7 +36,7 @@ REGISTER_SERIALIZABLE(Gl1_Aabb);
 
 class Gl1_Box : public GlShapeFunctor {
 public:
-	virtual void go(const shared_ptr<Shape>&, const shared_ptr<State>&, bool, const GLViewInfo&);
+	void go(const shared_ptr<Shape>&, const shared_ptr<State>&, bool, const GLViewInfo&) override;
 	RENDERS(Box);
 	// clang-format off
 	YADE_CLASS_BASE_DOC(Gl1_Box,GlShapeFunctor,"Renders :yref:`Box` object");
@@ -47,7 +47,7 @@ REGISTER_SERIALIZABLE(Gl1_Box);
 
 class Gl1_Facet : public GlShapeFunctor {
 public:
-	virtual void go(const shared_ptr<Shape>&, const shared_ptr<State>&, bool, const GLViewInfo&);
+	void go(const shared_ptr<Shape>&, const shared_ptr<State>&, bool, const GLViewInfo&) override;
 	RENDERS(Facet);
 	// clang-format off
 	YADE_CLASS_BASE_DOC_STATICATTRS(Gl1_Facet,GlShapeFunctor,"Renders :yref:`Facet` object",
@@ -78,7 +78,7 @@ private:
 	static char prevCircleAllowedRotationAxis;
 
 public:
-	virtual void go(const shared_ptr<Shape>&, const shared_ptr<State>&, bool, const GLViewInfo&);
+	void go(const shared_ptr<Shape>&, const shared_ptr<State>&, bool, const GLViewInfo&) override;
 	// clang-format off
 	YADE_CLASS_BASE_DOC_STATICATTRS(Gl1_Sphere,GlShapeFunctor,"Renders :yref:`Sphere` object",
 		((Real,quality,1.0,,"Change discretization level of spheres. quality>1  for better image quality, at the price of more cpu/gpu usage, 0<quality<1 for faster rendering. If mono-color spheres are displayed (:yref:`Gl1_Sphere::stripes` = False), quality mutiplies :yref:`Gl1_Sphere::glutSlices` and :yref:`Gl1_Sphere::glutStacks`. If striped spheres are displayed (:yref:`Gl1_Sphere::stripes` = True), only integer increments are meaningfull : quality=1 and quality=1.9 will give the same result, quality=2 will give finer result."))
