@@ -1,10 +1,9 @@
 // =======================================================
 // Some plugins from removed CPP-fiels
 
-#include <pkg/common/Aabb.hpp>
+#include <core/Aabb.hpp>
 #include <pkg/common/BoundaryController.hpp>
 #include <pkg/common/Box.hpp>
-#include <pkg/common/Callbacks.hpp>
 #include <pkg/common/CylScGeom6D.hpp>
 #include <pkg/common/ElastMat.hpp>
 #include <pkg/common/FieldApplier.hpp>
@@ -20,13 +19,7 @@
 
 namespace yade { // Cannot have #include directive inside.
 
-YADE_PLUGIN((IntrCallback)
-#ifdef YADE_BODY_CALLBACK
-                    (BodyCallback)
-#endif
-);
-
 YADE_PLUGIN((ForceResetter)(TorqueEngine)(FieldApplier)(BoundaryController)(NormPhys)(NormShearPhys)(Recorder)(CylScGeom6D)(CylScGeom)(Box)(StepDisplacer)(
-        GenericSpheresContact)(PeriodicEngine)(Sphere)(Aabb)(ElastMat)(FrictMat)(PyRunner));
+        GenericSpheresContact)(PeriodicEngine)(Sphere)(ElastMat)(FrictMat)(PyRunner));
 
 } // namespace yade
