@@ -1,13 +1,13 @@
 // 2007,2008 © Václav Šmilauer <eudoxos@arcig.cz>
 #include "ConcretePM.hpp"
 #include <lib/high-precision/Constants.hpp>
+#include <core/InteractionLoop.hpp>
 #include <core/Scene.hpp>
 #include <pkg/common/Box.hpp>
 #include <pkg/common/Facet.hpp>
-#include <pkg/common/InteractionLoop.hpp>
 #include <pkg/common/Wall.hpp>
 #include <pkg/dem/DemXDofGeom.hpp>
-#include <pkg/dem/Shop.hpp>
+#include <preprocessing/dem/Shop.hpp>
 
 #ifdef YADE_OPENGL
 #include <lib/opengl/GLUtils.hpp>
@@ -43,8 +43,7 @@ CREATE_LOGGER(Ip2_CpmMat_CpmMat_CpmPhys);
 void Ip2_CpmMat_CpmMat_CpmPhys::go(const shared_ptr<Material>& pp1, const shared_ptr<Material>& pp2, const shared_ptr<Interaction>& interaction)
 {
 	// no updates of an already existing contact necessary
-	if (interaction->phys)
-		return;
+	if (interaction->phys) return;
 	TIMING_DELTAS_START();
 	shared_ptr<CpmPhys> cpmPhys(new CpmPhys());
 	interaction->phys = cpmPhys;
@@ -131,8 +130,7 @@ Real CpmPhys::solveBeta(const Real c, const Real N)
 #endif
 		Real aux = c * exp(N * ret) + exp(ret);
 		f        = log(aux);
-		if (math::abs(f) < maxError)
-			return ret;
+		if (math::abs(f) < maxError) return ret;
 		Real df = (c * N * exp(N * ret) + exp(ret)) / aux;
 		ret -= f / df;
 	}
@@ -158,8 +156,7 @@ Real CpmPhys::computeDmgOverstress(Real dt)
 
 Real CpmPhys::computeViscoplScalingFactor(Real sigmaTNorm, Real sigmaTYield, Real dt)
 {
-	if (sigmaTNorm < sigmaTYield)
-		return 1.;
+	if (sigmaTNorm < sigmaTYield) return 1.;
 	Real c    = undamagedCohesion * pow(plTau / (G * dt), plRateExp) * pow(sigmaTNorm - sigmaTYield, plRateExp - 1.);
 	Real beta = solveBeta(c, plRateExp);
 	//LOG_DEBUG("scaling factor "<<1.-exp(beta)*(1-sigmaTYield/sigmaTNorm));
@@ -168,13 +165,13 @@ Real CpmPhys::computeViscoplScalingFactor(Real sigmaTNorm, Real sigmaTYield, Rea
 
 Real CpmPhys::funcG(const Real& kappaD, const Real& epsCrackOnset, const Real& epsFracture, const bool& neverDamage, const int& damLaw)
 {
-	if (kappaD < epsCrackOnset || neverDamage)
-		return 0;
+	if (kappaD < epsCrackOnset || neverDamage) return 0;
 	switch (damLaw) {
 		case 0: // linear
 			return (1. - epsCrackOnset / kappaD) / (1. - epsCrackOnset / epsFracture);
 		case 1: // exponential
 			return 1. - (epsCrackOnset / kappaD) * exp(-(kappaD - epsCrackOnset) / epsFracture);
+		default: throw std::runtime_error(__FILE__ " : switch default case error.");
 	}
 	throw runtime_error("CpmPhys::funcG: wrong damLaw\n");
 }
@@ -186,18 +183,18 @@ Real CpmPhys::funcGDKappa(const Real& kappaD, const Real& epsCrackOnset, const R
 			return epsCrackOnset / ((1. - epsCrackOnset / epsFracture) * kappaD * kappaD);
 		case 1: // exponential
 			return epsCrackOnset / kappaD * (1. / kappaD + 1. / epsFracture) * exp(-(kappaD - epsCrackOnset) / epsFracture);
+		default: throw std::runtime_error(__FILE__ " : switch default case error.");
 	}
 	throw runtime_error("CpmPhys::funcGDKappa: wrong damLaw\n");
 }
 
 Real CpmPhys::funcGInv(const Real& omega, const Real& epsCrackOnset, const Real& epsFracture, const bool& neverDamage, const int& damLaw)
 {
-	if (omega == 0. || neverDamage)
-		return 0;
+	if (omega == 0. || neverDamage) return 0;
 	switch (damLaw) {
 		case 0: // linear
 			return epsCrackOnset / (1. - omega * (1. - epsCrackOnset / epsFracture));
-		case 1: // exponential
+		case 1: { // exponential
 			// Newton's iterations
 			Real fg, dfg, decr, ret = epsCrackOnset, tol = 1e-3;
 			int  maxIter = 100;
@@ -207,29 +204,25 @@ Real CpmPhys::funcGInv(const Real& omega, const Real& epsCrackOnset, const Real&
 				dfg  = CpmPhys::funcGDKappa(ret, epsCrackOnset, epsFracture, neverDamage, damLaw);
 				decr = fg / dfg;
 				ret -= decr;
-				if (math::abs(decr / epsCrackOnset) < tol) {
-					return ret;
-				}
+				if (math::abs(decr / epsCrackOnset) < tol) { return ret; }
 			}
 			throw runtime_error("CpmPhys::funcGInv: no convergence\n");
+		} break;
+		default: throw std::runtime_error(__FILE__ " : switch default case error.");
 	}
 	throw runtime_error("CpmPhys::funcGInv: wrong damLaw\n");
 }
 
 void CpmPhys::setDamage(Real dmg)
 {
-	if (neverDamage) {
-		return;
-	}
+	if (neverDamage) { return; }
 	omega  = dmg;
 	kappaD = CpmPhys::funcGInv(dmg, epsCrackOnset, epsFracture, neverDamage, damLaw);
 }
 
 void CpmPhys::setRelResidualStrength(Real r)
 {
-	if (neverDamage) {
-		return;
-	}
+	if (neverDamage) { return; }
 	if (r == 1.) {
 		relResidualStrength = r;
 		kappaD = omega = 0.;
@@ -275,8 +268,7 @@ Real Law2_ScGeom_CpmPhys_Cpm::elasticEnergy()
 	Real ret = 0.;
 	FOREACH(const shared_ptr<Interaction>& I, *scene->interactions)
 	{
-		if (!I->isReal())
-			continue;
+		if (!I->isReal()) continue;
 		CpmPhys* phys = dynamic_cast<CpmPhys*>(I->phys.get());
 		if (phys) {
 			ret += 0.5 * phys->normalForce.squaredNorm() / ((1 - (phys->epsN > 0 ? phys->omega : 0)) * phys->kn);
@@ -368,7 +360,12 @@ bool Law2_ScGeom_CpmPhys_Cpm::go(shared_ptr<IGeom>& _geom, shared_ptr<IPhys>& _p
 	const Real& tanFrictionAngle(phys->tanFrictionAngle);
 	const Real& G(phys->G);
 	const Real& crossSection(phys->crossSection);
+// FIXME - remove this pragma. Fixing omegaThreshold shadow is to be done later.
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpragmas"
+#pragma GCC diagnostic ignored "-Wshadow"
 	const Real& omegaThreshold(this->omegaThreshold);
+#pragma GCC diagnostic pop
 	const Real& epsCrackOnset(phys->epsCrackOnset);
 	Real&       relResidualStrength(phys->relResidualStrength);
 	/*const Real& relDuctility(phys->relDuctility); */
@@ -391,9 +388,14 @@ bool Law2_ScGeom_CpmPhys_Cpm::go(shared_ptr<IGeom>& _geom, shared_ptr<IPhys>& _p
 	const int&  yieldSurfType(this->yieldSurfType);
 	const Real& yieldEllipseShift(this->yieldEllipseShift);
 #endif
-	Real&       epsNPl(phys->epsNPl);
+	Real& epsNPl(phys->epsNPl);
+// FIXME - remove this pragma. Fixing epsSoft and relKnSoft shadow is to be done later.
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpragmas"
+#pragma GCC diagnostic ignored "-Wshadow"
 	const Real& epsSoft(this->epsSoft);
 	const Real& relKnSoft(this->relKnSoft);
+#pragma GCC diagnostic pop
 
 	TIMING_DELTAS_CHECKPOINT("GO A");
 
@@ -518,35 +520,34 @@ void Gl1_CpmPhys::go(
 	const shared_ptr<CpmPhys>&               phys = boost::static_pointer_cast<CpmPhys>(ip);
 	const shared_ptr<GenericSpheresContact>& geom = YADE_PTR_CAST<GenericSpheresContact>(i->geom);
 	// FIXME: get the scene for periodicity; ugly!
-	Scene* scene = Omega::instance().getScene().get();
+	// declaration of ‘scene’ shadows a member of ‘yade::Gl1_CpmPhys’ [-Werror=shadow]
+	Scene* scene2 = Omega::instance().getScene().get();
 
 	//Vector3r lineColor(phys->omega,1-phys->omega,0.0); /* damaged links red, undamaged green */
 	Vector3r lineColor = Shop::scalarOnColorScale(1. - phys->relResidualStrength);
 
-	if (colorStrainRatio > 0)
-		lineColor = Shop::scalarOnColorScale(phys->epsN / (phys->epsCrackOnset * colorStrainRatio));
+	if (colorStrainRatio > 0) lineColor = Shop::scalarOnColorScale(phys->epsN / (phys->epsCrackOnset * colorStrainRatio));
 
 	// FIXME: should be computed by the renderer; for now, use the real values
 	//Vector3r pos1=geom->se31.position, pos2=geom->se32.position;
-	Vector3r pos1 = scene->bodies->operator[](i->id1)->state->pos, pos2 = scene->bodies->operator[](i->id2)->state->pos;
-	if (scene->isPeriodic) {
+	Vector3r pos1 = scene2->bodies->operator[](i->id1)->state->pos, pos2 = scene2->bodies->operator[](i->id2)->state->pos;
+	if (scene2->isPeriodic) {
 		Vector3r dPos   = pos2 - pos1;
-		pos1            = scene->cell->wrapShearedPt(pos1);
-		Vector3r shift2 = scene->isPeriodic ? Vector3r(scene->cell->hSize * i->cellDist.cast<Real>()) : Vector3r::Zero();
+		pos1            = scene2->cell->wrapShearedPt(pos1);
+		Vector3r shift2 = scene2->isPeriodic ? Vector3r(scene2->cell->hSize * i->cellDist.cast<Real>()) : Vector3r::Zero();
 		pos2            = pos1 + dPos + shift2;
 		//phys->refLength = (pos2 - pos1 + shift2).norm();
 		//pos2=pos1+(geom->se32.position-geom->se31.position);
 	}
 	/*
-		if (scene->isPeriodic) {
+		if (scene2->isPeriodic) {
 			Vector3r temp = pos2 - pos1;
-			pos1 = scene->cell->wrapShearedPt(pos1);
+			pos1 = scene2->cell->wrapShearedPt(pos1);
 			pos2 = pos1 + temp;
 		}
 		*/
 
-	if (contactLine)
-		GLUtils::GLDrawLine(pos1, pos2, lineColor);
+	if (contactLine) GLUtils::GLDrawLine(pos1, pos2, lineColor);
 	if (dmgLabel) {
 		GLUtils::GLDrawNum(phys->omega, 0.5 * (pos1 + pos2), lineColor);
 	} else if (epsNLabel) {
@@ -576,9 +577,7 @@ void Gl1_CpmPhys::go(
 	}
 
 	Vector3r cp = boost::static_pointer_cast<GenericSpheresContact>(i->geom)->contactPoint;
-	if (scene->isPeriodic) {
-		cp = scene->cell->wrapShearedPt(cp);
-	}
+	if (scene2->isPeriodic) { cp = scene2->cell->wrapShearedPt(cp); }
 	if (epsT) {
 		Real     maxShear = (phys->undamagedCohesion - phys->sigmaN * phys->tanFrictionAngle) / phys->G;
 		Real     relShear = phys->epsT.norm() / maxShear;
@@ -607,24 +606,22 @@ CREATE_LOGGER(CpmStateUpdater);
 
 void CpmStateUpdater::update(Scene* _scene)
 {
-	Scene*            scene = _scene ? _scene : Omega::instance().getScene().get();
+	// declaration of ‘scene’ shadows a member of ‘yade::CpmStateUpdater’ [-Werror=shadow]
+	Scene*            scene2 = _scene ? _scene : Omega::instance().getScene().get();
 	vector<BodyStats> bodyStats;
-	bodyStats.resize(scene->bodies->size());
+	bodyStats.resize(scene2->bodies->size());
 	assert(bodyStats[0].nCohLinks == 0); // should be initialized by dfault ctor
 	avgRelResidual           = 0;
 	Real     nAvgRelResidual = 0;
 	Matrix3r identity        = Matrix3r::Identity();
 	Real     dmg;
 	Matrix3r incr;
-	FOREACH(const shared_ptr<Interaction>& I, *scene->interactions)
+	FOREACH(const shared_ptr<Interaction>& I, *scene2->interactions)
 	{
-		if (!I)
-			continue;
-		if (!I->isReal())
-			continue;
+		if (!I) continue;
+		if (!I->isReal()) continue;
 		shared_ptr<CpmPhys> phys = YADE_PTR_DYN_CAST<CpmPhys>(I->phys);
-		if (!phys)
-			continue;
+		if (!phys) continue;
 		const Body::id_t       id1 = I->getId1(), id2 = I->getId2();
 		GenericSpheresContact* geom = YADE_CAST<GenericSpheresContact*>(I->geom.get());
 
@@ -640,8 +637,7 @@ void CpmStateUpdater::update(Scene* _scene)
 		bodyStats[id1].nLinks++;
 		bodyStats[id2].nLinks++;
 
-		if (!phys->isCohesive)
-			continue;
+		if (!phys->isCohesive) continue;
 		bodyStats[id1].nCohLinks++;
 		bodyStats[id1].dmgSum += (1 - phys->relResidualStrength); // bodyStats[id1].epsPlSum += phys->epsPlSum;
 		bodyStats[id2].nCohLinks++;
@@ -659,15 +655,13 @@ void CpmStateUpdater::update(Scene* _scene)
 		}
 	}
 	// 	Real tr;
-	FOREACH(shared_ptr<Body> B, *scene->bodies)
+	FOREACH(shared_ptr<Body> B, *scene2->bodies)
 	{
-		if (!B)
-			continue;
+		if (!B) continue;
 		const Body::id_t& id = B->getId();
 		// add damaged contacts that have already been deleted
 		CpmState* state = dynamic_cast<CpmState*>(B->state.get());
-		if (!state)
-			continue;
+		if (!state) continue;
 		state->stress        = bodyStats[id].stress;
 		int cohLinksWhenever = bodyStats[id].nCohLinks + state->numBrokenCohesive;
 		if (cohLinksWhenever > 0) {
@@ -686,8 +680,7 @@ void CpmStateUpdater::update(Scene* _scene)
 		B->shape->color = Vector3r(state->normDmg, 1 - state->normDmg, B->state->blockedDOFs == State::DOF_ALL ? 0 : 1);
 		nAvgRelResidual += 0.5 * state->numBrokenCohesive; // add half or broken interactions, other body has the other half
 		Sphere* sphere = dynamic_cast<Sphere*>(B->shape.get());
-		if (!sphere)
-			continue;
+		if (!sphere) continue;
 		Real& r       = sphere->radius;
 		state->stress = bodyStats[id].stress / (4 / 3. * Mathr::PI * r * r * r / .62) * .5;
 	}
