@@ -10,7 +10,6 @@
 
 #include "TesselationWrapper.hpp"
 #include <lib/high-precision/Constants.hpp>
-#include <lib/triangulation/Timer.h>
 #include <preprocessing/dem/Shop.hpp>
 #include <preprocessing/dem/SpherePack.hpp>
 
@@ -23,6 +22,14 @@
 #include <lib/pyutil/numpy_boost.hpp>
 #pragma GCC diagnostic pop
 
+#ifdef YADE_OPENGL
+#include <lib/opengl/GLUtils.hpp>
+#include <lib/opengl/OpenGLWrapper.hpp>
+#include <pkg/common/GLDrawFunctors.hpp>
+#include <chrono>
+#include <thread>
+#endif
+
 namespace yade { // Cannot have #include directive inside.
 
 using math::max;
@@ -171,11 +178,11 @@ void TesselationWrapper::clear2(void) //for testing purpose
 void TesselationWrapper::insertSceneSpheres(bool reset)
 {
 	// declaration of ‘scene’ shadows a member of ‘yade::TesselationWrapper’ [-Werror=shadow]
-	Scene* scene2 = Omega::instance().getScene().get();
+	// 	Scene* scene2 = Omega::instance().getScene().get();
 	// 	Real_timer clock;
 	//         clock.start();
-	const shared_ptr<BodyContainer>& bodies = scene2->bodies;
-	build_triangulation_with_ids(bodies, *this, reset);
+	// 	const shared_ptr<BodyContainer>& bodies = scene2->bodies;
+	build_triangulation_with_ids(scene->bodies, *this, reset);
 	// 	clock.top("Triangulation");
 }
 
@@ -252,6 +259,34 @@ bool TesselationWrapper::nextFacet(std::pair<unsigned int, unsigned int>& facet)
 	return true;
 }
 
+int TesselationWrapper::addBoundingPlane(short axis, bool positive)
+{
+	Vector3r cornerMin   = Vector3r(Pmin.x(), Pmin.y(), Pmin.z());
+	Vector3r cornerMax   = Vector3r(Pmax.x(), Pmax.y(), Pmax.z());
+	Vector3r halfSize    = 0.5 * (cornerMax - cornerMin);
+	Vector3r centerPoint = 0.5 * (cornerMin + cornerMax);
+	// shift by half-size + a large radius
+	Vector3r shift = Vector3r::Zero();
+	shift[axis]    = positive ? 1 : -1;
+	shift *= far * (cornerMax - cornerMin).norm();
+	shift[axis] += positive ? halfSize[axis] : -halfSize[axis];
+	centerPoint += shift;
+
+	//find a free id
+	int freeId = 0;
+	while (Tes->vertexHandles[freeId] != NULL)
+		++freeId;
+
+	// we don't want to count this virtual sphere's radius in the average, so compute it before inserting
+	if (!rad_divided) {
+		mean_radius /= n_spheres;
+		rad_divided = true;
+	}
+	// now insert
+	Tes->vertexHandles[freeId] = Tes->insert(centerPoint[0], centerPoint[1], centerPoint[2], far * (cornerMax - cornerMin).norm(), freeId, false);
+	return freeId;
+}
+
 void TesselationWrapper::addBoundingPlanes(Real pminx, Real pmaxx, Real pminy, Real pmaxy, Real pminz, Real pmaxz)
 {
 	if (!bounded) {
@@ -270,13 +305,13 @@ void TesselationWrapper::addBoundingPlanes(Real pminx, Real pmaxx, Real pminy, R
 		}
 		// now insert
 		Tes->vertexHandles[freeIds[0]] = Tes->insert(
-		        0.5 * (pminx + pmaxx), pminy - far * (pmaxx - pminx), 0.5 * (pmaxz + pminz), far * (pmaxx - pminx) + thickness, freeIds[0], true);
+		        pminx - far * (pmaxy - pminy), 0.5 * (pmaxy + pminy), 0.5 * (pmaxz + pminz), far * (pmaxy - pminy) + thickness, freeIds[0], true);
 		Tes->vertexHandles[freeIds[1]] = Tes->insert(
-		        0.5 * (pminx + pmaxx), pmaxy + far * (pmaxx - pminx), 0.5 * (pmaxz + pminz), far * (pmaxx - pminx) + thickness, freeIds[1], true);
+		        pmaxx + far * (pmaxy - pminy), 0.5 * (pmaxy + pminy), 0.5 * (pmaxz + pminz), far * (pmaxy - pminy) + thickness, freeIds[1], true);
 		Tes->vertexHandles[freeIds[2]] = Tes->insert(
-		        pminx - far * (pmaxy - pminy), 0.5 * (pmaxy + pminy), 0.5 * (pmaxz + pminz), far * (pmaxy - pminy) + thickness, freeIds[2], true);
+		        0.5 * (pminx + pmaxx), pminy - far * (pmaxx - pminx), 0.5 * (pmaxz + pminz), far * (pmaxx - pminx) + thickness, freeIds[2], true);
 		Tes->vertexHandles[freeIds[3]] = Tes->insert(
-		        pmaxx + far * (pmaxy - pminy), 0.5 * (pmaxy + pminy), 0.5 * (pmaxz + pminz), far * (pmaxy - pminy) + thickness, freeIds[3], true);
+		        0.5 * (pminx + pmaxx), pmaxy + far * (pmaxx - pminx), 0.5 * (pmaxz + pminz), far * (pmaxx - pminx) + thickness, freeIds[3], true);
 		Tes->vertexHandles[freeIds[4]] = Tes->insert(
 		        0.5 * (pminx + pmaxx), 0.5 * (pmaxy + pminy), pminz - far * (pmaxy - pminy), far * (pmaxy - pminy) + thickness, freeIds[4], true);
 		Tes->vertexHandles[freeIds[5]] = Tes->insert(
@@ -391,7 +426,7 @@ boost::python::dict TesselationWrapper::calcVolPoroDef(bool deformation)
 	return ret;
 }
 
-boost::python::list TesselationWrapper::getAlphaFaces(Real alpha) const
+boost::python::list TesselationWrapper::getAlphaFaces(Real alpha)
 {
 	vector<AlphaFace> faces;
 	Tes->setAlphaFaces(faces, alpha);
@@ -401,7 +436,7 @@ boost::python::list TesselationWrapper::getAlphaFaces(Real alpha) const
 	return ret;
 }
 
-boost::python::list TesselationWrapper::getAlphaCaps(Real alpha, Real shrinkedAlpha, bool fixedAlpha) const
+boost::python::list TesselationWrapper::getAlphaCaps(Real alpha, Real shrinkedAlpha, bool fixedAlpha)
 {
 	vector<AlphaCap> caps;
 	Tes->setExtendedAlphaCaps(caps, alpha, shrinkedAlpha, fixedAlpha);
@@ -412,16 +447,19 @@ boost::python::list TesselationWrapper::getAlphaCaps(Real alpha, Real shrinkedAl
 	return ret;
 }
 
-void TesselationWrapper::applyAlphaForces(Matrix3r stress, Real alpha, Real shrinkedAlpha, bool fixedAlpha)
+void TesselationWrapper::applyAlphaForces(Matrix3r stress, Real alpha, Real shrinkedAlpha, bool fixedAlpha, bool reset)
 {
 	// Scene* scene = Omega::instance().getScene().get();
-	build_triangulation_with_ids(scene->bodies, *this, true); //triangulation needed
+	if ((Tes->Triangulation().number_of_vertices() == 0) or reset) insertSceneSpheres(true);
+	// 	build_triangulation_with_ids(scene->bodies, *this, true); //triangulation needed
 	vector<AlphaCap> caps;
 	Tes->setExtendedAlphaCaps(caps, alpha, shrinkedAlpha, fixedAlpha);
 	for (const auto& b : *scene->bodies)
 		scene->forces.setPermForce(b->id, Vector3r::Zero());
-	for (auto f = caps.begin(); f != caps.end(); f++)
+	for (auto f = caps.begin(); f != caps.end(); f++) {
+		if (not scene->bodies->exists(f->id)) continue; // FIXME: probably not needed
 		scene->forces.setPermForce(f->id, stress * makeVector3r(f->normal));
+	}
 }
 
 void TesselationWrapper::applyAlphaVel(Matrix3r velGrad, Real alpha, Real shrinkedAlpha, bool fixedAlpha)
@@ -462,16 +500,17 @@ Matrix3r TesselationWrapper::calcAlphaStress(Real alpha, Real shrinkedAlpha, boo
 	return cauchyLWS;
 }
 
-boost::python::list TesselationWrapper::getAlphaGraph(Real alpha, Real shrinkedAlpha, bool fixedAlpha) const
+boost::python::list TesselationWrapper::getAlphaGraph(Real alpha, Real shrinkedAlpha, bool fixedAlpha)
 {
-	vector<Vector3r>    segments = Tes->getExtendedAlphaGraph(alpha, shrinkedAlpha, fixedAlpha);
+	if (Tes->Triangulation().number_of_vertices() == 0) insertSceneSpheres(true);
+	segments = Tes->getExtendedAlphaGraph(alpha, shrinkedAlpha, fixedAlpha);
 	boost::python::list ret;
 	for (auto f = segments.begin(); f != segments.end(); f++)
 		ret.append(*f);
 	return ret;
 }
 
-boost::python::list TesselationWrapper::getAlphaVertices(Real alpha) const
+boost::python::list TesselationWrapper::getAlphaVertices(Real alpha)
 {
 	vector<int>         vertices = Tes->getAlphaVertices(alpha);
 	boost::python::list ret;
@@ -480,6 +519,91 @@ boost::python::list TesselationWrapper::getAlphaVertices(Real alpha) const
 	return ret;
 }
 
+#ifdef YADE_OPENGL
+
+YADE_PLUGIN((GlExtra_AlphaGraph))
+
+GLUquadric* GlExtra_AlphaGraph::gluQuadric     = NULL;
+int         GlExtra_AlphaGraph::glCylinderList = -1;
+int         GlExtra_AlphaGraph::oneCylinder    = -1;
+
+void GlExtra_AlphaGraph::render()
+{
+	if (not tesselationWrapper) tesselationWrapper = shared_ptr<TesselationWrapper>(new TesselationWrapper);
+	if (tesselationWrapper->Tes->Triangulation().number_of_vertices() == 0) tesselationWrapper->insertSceneSpheres(true);
+	if (tesselationWrapper->segments.size() == 0 or reset) {
+#ifdef BREAK_OPENGL
+		segments =
+#endif
+		        tesselationWrapper->segments = tesselationWrapper->Tes->getExtendedAlphaGraph(alpha, shrinkedAlpha, fixedAlpha);
+		reset                                = true;
+	}
+#ifdef BREAK_OPENGL
+	else
+		segments = tesselationWrapper->segments;
+#endif
+	if ((reset or refreshDisplay) and not wire) {
+		rots.clear();
+		lengths.clear();
+	}
+	// 	const vector<Vector3r>& segments_ = segments;
+	const vector<Vector3r>& segments_ = tesselationWrapper->segments;
+	unsigned                maxI      = segments_.size() - 1;
+	glLineWidth(lineWidth);
+	glColor3v(color);
+	if (lighting) glEnable(GL_LIGHTING);
+	else
+		glDisable(GL_LIGHTING);
+	glDisable(GL_CULL_FACE);
+	if ((rots.size() == 0 or reset or refreshDisplay) and not wire) {
+		Real     radiusTemp = 0;
+		unsigned i          = 0;
+		while (i < maxI) {
+			const Vector3r& p1     = segments_[i];
+			const Vector3r& p2     = segments_[i + 1];
+			Vector3r        relPos = p2 - p1;
+			Real            length = relPos.norm();
+			lengths.push_back(length);
+			rots.push_back(Eigen::Transform<Real, 3, Eigen::Affine>(Quaternionr().setFromTwoVectors(Vector3r(0, 0, 1), relPos / length)));
+			radiusTemp += length;
+			i += 2;
+		}
+		if (radius == 0) radius = radiusTemp / Real(i * 3);
+		reset = false;
+	}
+	if (glCylinderList < 0) // will always be true unless the glGenLists() below is commented in (not sure it helps, should be tested)
+	{
+		unsigned i = 0, jj = 0;
+		if (!gluQuadric) {
+			gluQuadric = gluNewQuadric();
+			if (!gluQuadric) throw runtime_error("Gl1_NormPhys::go unable to allocate new GLUquadric object (out of memory?).");
+		}
+		// 		glCylinderList = glGenLists(1);
+		// 		glNewList(glCylinderList, GL_COMPILE); // create the list here, call it after the "if{}".
+		while (i < maxI) {
+			const Vector3r& p1 = segments_[i];
+			const Vector3r& p2 = segments_[i + 1];
+			if (wire) {
+				glBegin(GL_LINES)
+					;
+					glVertex3v(p1);
+					glVertex3v(p2);
+				glEnd();
+			} else {
+				glPushMatrix();
+				glTranslatev(p1);
+				glMultMatrix(rots[jj].data());
+				gluCylinder(gluQuadric, radius, radius, lengths[jj], 4, 1);
+				glPopMatrix();
+			}
+			i += 2;
+			++jj;
+		}
+	}
+	// 	glCallList(glCylinderList);
+}
+#endif /*OPENGL*/
+
 } // namespace yade
 
 #endif /* YADE_CGAL */
