@@ -9,8 +9,8 @@
 #include <core/Scene.hpp>
 #include <pkg/levelSet/LevelSet.hpp>
 #include <pkg/levelSet/ShopLS.hpp>
-#include <preprocessing/dem/Shop.hpp>
 #include <boost/math/tools/roots.hpp>
+#include <preprocessing/dem/Shop.hpp>
 
 namespace yade {
 YADE_PLUGIN((LevelSet));
@@ -25,6 +25,12 @@ Vector3r LevelSet::getCenter()
 // // vector<int> LevelSet::getNodesInCellCube(int i, int j, int k){ Vector3i ?
 // // 	return nodesIndicesInCell[Vector3i(i,j,k)];
 // // }
+Real LevelSet::smearedHeaviside(Real x)
+{
+	// Passing smoothly (increasing sine-sort) from y = 0 to 1 when x goes from -1 to 1, see Eq. (3) of Kawamoto2016.
+	return 0.5 * (1.0 + x + sin(Mathr::PI * x) / Mathr::PI);
+}
+
 void LevelSet::rayTrace(const Vector3r& ray)
 {
 	// we launch a ray from shape's center (= 0), and go through all grid cells until the end of the grid, looking for ray-surface intersection
@@ -52,7 +58,7 @@ void LevelSet::rayTrace(const Vector3r& ray)
 		diffSign = false;
 		for (unsigned int gp = 0; gp < 8; gp++) { // passing through 8 cell gridpoints to check whether they all have the same distance sign
 			xInd   = (gp % 2 ? indices[0] + 1
-                                       : indices[0]); // better put parenthesis: "=" and ternary have same precedence, let s not look at associativity
+			                 : indices[0]); // better put parenthesis: "=" and ternary have same precedence, let s not look at associativity
 			yInd   = ((gp & 2) / 2 ? indices[1] + 1 : indices[1]);
 			zInd   = ((gp & 4) / 4 ? indices[2] + 1 : indices[2]);
 			gpDist = distField[xInd][yInd][zInd]; // distance value for current gp
@@ -149,8 +155,10 @@ bool LevelSet::rayTraceInCell(const Vector3r& ray, const Vector3r& pointP, const
 	LOG_INFO(
 	        "We think finding surface-ray intersection is like finding the roots of this polynom (coeffs of increasing order):\n"
 	        << coeffs[0] << " " << coeffs[1] << " " << coeffs[2] << " " << coeffs[3]);
-	// Then, solving for the 1st root given by Boost root finding algorithm boost::math::tools::newton_raphson_iterate, in a -2 line syntax thanks to this C++11 lambda notation, that replaces going through e.g. an operator() of some struct (whose instance may depend on coeffs)
-	Real root(boost::math::tools::newton_raphson_iterate(
+	// Then, solving for the 1st root given by Boost root finding algorithm boost::math::tools::newton_raphson_iterate, in a concise syntax thanks to C++11 lambda notation, that replaces going through e.g. an operator() of some struct (whose instance may depend on coeffs)
+	Real root(std::numeric_limits<Real>::max());
+	try{
+	  root=boost::math::tools::newton_raphson_iterate(
 	        [coeffs](Real k) {
 		        return std::make_tuple( // (only ?) problematic part for High Precision (HP) compatibility and REAL_* cmake options different than 64
 		                coeffs[0] + coeffs[1] * k + coeffs[2] * k * k + coeffs[3] * k * k * k,
@@ -160,7 +168,10 @@ bool LevelSet::rayTraceInCell(const Vector3r& ray, const Vector3r& pointP, const
 	        -sqrt(3.),
 	        sqrt(3.),
 	        std::numeric_limits<Real>::
-	                digits)); // doc https://www.boost.org/doc/libs/1_75_0/libs/math/doc/html/math_toolkit/roots_deriv.html suggests to use 0.6 * std::numeric_limits<Real>::digits for the last "digits" argument. With std::numeric_limits<double>::digits = 53, as per standard for the significand
+		        digits); // doc https://www.boost.org/doc/libs/1_75_0/libs/math/doc/html/math_toolkit/roots_deriv.html suggests to use 0.6 * std::numeric_limits<Real>::digits for the last "digits" argument. With std::numeric_limits<double>::digits = 53, as per standard for the significand
+	}
+	catch(const std::exception& e) // starting from somewhere between boost 1.71.0 and 1.74.0, a boost::math::evaluation_error is thrown if no root is found, which can be catched as a std::exception
+	  {LOG_INFO("No root actually found");};
 	LOG_INFO(
 	        "N-R root = " << root << " , leading to a dimensionless distance (through the ray cubic polynom) = "
 	                      << coeffs[0] + coeffs[1] * root + coeffs[2] * root * root + coeffs[3] * root * root * root
@@ -183,15 +194,15 @@ bool LevelSet::rayTraceInCell(const Vector3r& ray, const Vector3r& pointP, const
 	                / spac << " ; while nodesTol*epsilon = " << nodesTol * Mathr::EPSILON);
 	if (surfNodes.size() > 0)
 		LOG_INFO(
-		        "And previous node is " << surfNodes.back() << " whose comparison with gives (in absolute norm)"
+		        "And previous node is " << surfNodes.back() << " whose comparison with gives (relative difference through norms)"
 		                                << (trialNode - surfNodes.back()).norm() / (surfNodes.back()).norm());
 	if ((math::abs(distance(trialNode)) / lengthChar < nodesTol * Mathr::EPSILON)
-	    && // looks like we found a node. Root finding algorithm normally had a Mathr::EPSILON precision wrt to spac but distance() computation is not the same, hence a different precision. Which is finally estimated here from lengthChar (which matters more than spac)
-	    (surfNodes.size() == 0
-	     || ((trialNode - surfNodes.back()).norm() / surfNodes.back().norm() > lengthChar * nodesTol
-	                 * Mathr::
-	                         EPSILON)) // but we still do not want a duplicate of last node, that would come from an adjacent cell, with phi=0 on the cell surface(s)
-	) {
+	    // looks like we found a node. Root finding algorithm normally had a Mathr::EPSILON precision wrt to spac but distance() computation is not the same, hence a different precision. Which is finally estimated here from lengthChar (which matters more than spac)
+	    && (surfNodes.size() == 0 || ((trialNode - surfNodes.back()).norm() / lengthChar > nodesTol * Mathr::EPSILON)
+	        // but we still do not want a duplicate of last node, that would come from an adjacent cell, with phi=0 on the cell surface(s)
+	        // NB: the 2 above tests are somewhat contradictory in terms of nodesTol (whose value should not be neither too small (phi = 0 could not be checked and more duplicate) nor too big (phi = 0 could be false positive and false positive in duplicate test). What about a 1e-7 hardcoded ?..
+	        // NB2: maybe we do not need lChar.. (and just divide with trialNode.norm())
+	        )) {
 		LOG_INFO(
 		        "ONE NODE FOUND ! (" << trialNode << "): it would be in cell " << indicesPt << " whereas we considered cell " << indX << " " << indY
 		                             << " " << indZ);
@@ -204,21 +215,10 @@ bool LevelSet::rayTraceInCell(const Vector3r& ray, const Vector3r& pointP, const
 	return touched;
 }
 
-vector<Vector3r> LevelSet::marchingCubes()
-{
-	MarchingCube mc;
-	Vector3i     gpPerAxis = lsGrid->nGP;
-	int          nGPx(gpPerAxis[0]), nGPy(gpPerAxis[1]), nGPz(gpPerAxis[2]);
-	mc.init(nGPx, nGPy, nGPz, lsGrid->min, lsGrid->max());
-	mc.computeTriangulation(distField, 0);
-	vector<Vector3r> obtTriangles(mc.getTriangles()); // obtTriangles is here still much longer than 3*mc.getNbTriangles(), with a lot of garbage values
-	obtTriangles.resize(3 * mc.getNbTriangles());     // removing those garbage values
-	return obtTriangles;
-}
-
 Vector3r LevelSet::normal(const Vector3r& pt) const
 {
-	// returns the normal vector at pt, according to (2) Kawamoto2016
+	// Returns the normal vector at pt
+	// Checking which cell we're in:
 	Vector3i indices = lsGrid->closestCorner(pt);
 	int      xInd(indices[0]), yInd(indices[1]), zInd(indices[2]);
 
@@ -226,12 +226,13 @@ Vector3r LevelSet::normal(const Vector3r& pt) const
 		LOG_ERROR("Can not compute the normal, returning a NaN vector");
 		return Vector3r(NaN, NaN, NaN);
 	}
-
+	// Some declarations:
 	Real     spac   = lsGrid->spacing;
 	Vector3r corner = lsGrid->gridPoint(xInd, yInd, zInd);
 	Real     xRed((pt[0] - corner[0]) / spac), yRed((pt[1] - corner[1]) / spac),
-	        zRed((pt[2] - corner[2]) / spac); // dimensionless x,y,z of 3., top p. 4 Kawamoto2016
-	Real nx(0), ny(0), nz(0);                 // the x, y, z components of normal, computed below
+	        zRed((pt[2] - corner[2]) / spac); // dimensionless x,y,z in [0;1] in one cell (3., top p. 4 Kawamoto2016)
+	Real nx(0), ny(0), nz(0);                 // x, y, z components of normal
+	// Computing normal as the gradient of trilinear interpolation (e.g. Eq. (2) Kawamoto2016):
 	for (int indA = 0; indA < 2; indA++) {
 		for (int indB = 0; indB < 2; indB++) {
 			for (int indC = 0; indC < 2; indC++) {
@@ -242,7 +243,7 @@ Vector3r LevelSet::normal(const Vector3r& pt) const
 			}
 		}
 	}
-	return Vector3r(nx, ny, nz).normalized();
+	return Vector3r(nx, ny, nz).normalized(); // do we really need the normalized() ?.. normally, no
 }
 
 void LevelSet::initSurfNodes()
@@ -304,10 +305,18 @@ void LevelSet::init() // computes stuff (nVoxInside, center, volume, inertia, bo
 	if ((int(distField.size()) != nGPx) or (int((distField[0][0]).size()) != nGPz))
 		LOG_ERROR("There is a size-inconsistency between the current level set grid and shape.distField for this body! The level set grid has changed "
 		          "since the creation of this body, this is not supported.");
-	Real spac = lsGrid->spacing;
-	Real dV   = pow(spac, 3);
-	Real xMean(0), yMean(0), zMean(0); // the center of the level set volume, as determined below
+	Real spac  = lsGrid->spacing;
+	Real Vcell = pow(spac, 3);
+	Real phiRef(0.);
+	if (smearCoeff != 0)
+		phiRef = sqrt(3.0 / 4.0) * spac
+		        / smearCoeff; // Smearing parameter (reference distance value) for the smeared Heaviside step function. Equals the cell half-diagonal divided by smearCoeff.
+	else
+		LOG_WARN("You passed smearCoeff = 0, was that intended ? (there will be no smearing)");
+	Real xMean(0.), yMean(0.), zMean(0.); // the center of the level set volume, as determined below
 	nVoxInside = 0;
+	volume     = 0.0;      // Initializing volume to zero
+	Real     phi, dV(-1.); // Distance value and considered particle volume for the current cell (the latter can be less than Vcell due to smearing)
 	Vector3r gp;
 	// We will base our level set volume description upon the voxellised description using "inside" voxels.
 	// A voxel is said to be inside according to its minimum gridpoint only, boundary effects are thus unavoidable for now.
@@ -316,37 +325,53 @@ void LevelSet::init() // computes stuff (nVoxInside, center, volume, inertia, bo
 	     xIndex++) { // to nGPx-1 to avoid counting twice the last voxel (or the first if the test would consider the level set value at the max gridpoint)
 		for (int yIndex = 0; yIndex < nGPy - 1; yIndex++) {
 			for (int zIndex = 0; zIndex < nGPz - 1; zIndex++) {
-				if (distField[xIndex][yIndex][zIndex] <= 0) {
+				phi = distField[xIndex][yIndex][zIndex];
+				if (math::abs(phi) < phiRef)
+					dV = smearedHeaviside(-phi / phiRef)
+					        * Vcell; // we are within the smeared boundary (avoiding smearing if smearCoeff < 0)
+				else if (phi < 0)
+					dV = Vcell; // inside, and away from boundary
+				else if (phi > 0)
+					dV = 0.; // outside
+				if (dV > 0.) {
 					nVoxInside++;
+					volume += dV;
 					gp = lsGrid->gridPoint(xIndex, yIndex, zIndex);
-					xMean += gp[0] + spac / 2.;
-					yMean += gp[1] + spac / 2.;
-					zMean += gp[2] + spac / 2.;
+					xMean += (gp[0] + spac / 2.) * dV;
+					yMean += (gp[1] + spac / 2.) * dV;
+					zMean += (gp[2] + spac / 2.) * dV;
 				}
 			}
 		}
 	}
 	if (nVoxInside == 0)
 		LOG_ERROR(
-		        "We have a level set body with nVoxInside = 0, this is not expected neither supported."); // may happen when positive values restrict to point, line, or surface just along some lsGrid boundaries. Note that a body with only one gridpoint with a positive level set value, strictly within lsGrid, leads to a non zero volume
+		        "We have a level set body with 0 voxels being considered inside, this is not expected neither supported."); // may happen when positive values restrict to point, line, or surface just along some lsGrid boundaries. Note that a body with only one gridpoint with a positive level set value, strictly within lsGrid, leads to a non zero volume
 
-	volume = nVoxInside * dV;
-	xMean /= nVoxInside;
-	yMean /= nVoxInside;
-	zMean /= nVoxInside;
+	xMean /= volume;
+	yMean /= volume;
+	zMean /= volume;
 	center = Vector3r(xMean, yMean, zMean);
 	if (center.norm()
 	    > pow(3., 0.5) * spac) // possible offsets almost reach one voxel edge in 1D (e.g. an external but tangent voxel is considered to be inside)
 		LOG_ERROR(
 		        "Incorrect LevelSet description: shape center is equal to " << center << " in local axes, instead of 0 (modulo a " << spac
 		                                                                    << " grid spacing).");
-	// we had to first compute center before being able to compute inertia now (in a 2nd loop):
+	// Computing inertia in a 2nd loop, now that we firstd compute center above (in an unavoidable 1st loop):
 	Real Ixx(0), Ixy(0), Ixz(0), Iyy(0), Iyz(0), Izz(0);
 	Real xV, yV, zV;
 	for (int xIndex = 0; xIndex < nGPx - 1; xIndex++) { // we will stop before the last grid points to avoid counting twice the last (or first) voxels
 		for (int yIndex = 0; yIndex < nGPy - 1; yIndex++) {
 			for (int zIndex = 0; zIndex < nGPz - 1; zIndex++) {
-				if (distField[xIndex][yIndex][zIndex] <= 0) {
+				phi = distField[xIndex][yIndex][zIndex];
+				if (math::abs(phi) < phiRef)
+					dV = smearedHeaviside(-phi / phiRef)
+					        * Vcell; // we are within the smeared boundary (avoiding smearing if smearCoeff < 0)
+				else if (phi < 0)
+					dV = Vcell; // inside, and away from boundary
+				else if (phi > 0)
+					dV = 0.; // outside
+				if (dV > 0.) {
 					gp = lsGrid->gridPoint(xIndex, yIndex, zIndex);
 					xV = gp[0] + spac / 2.; // again, we choose taking the middle of this inside voxel, instead of the gridpoint
 					yV = gp[1] + spac / 2.;
@@ -361,17 +386,24 @@ void LevelSet::init() // computes stuff (nVoxInside, center, volume, inertia, bo
 			}
 		}
 	}
-	if (math::abs(Ixy) + math::abs(Ixz) + math::abs(Iyz) > 9.e-3 * (math::abs(Ixx) + math::abs(Iyy) + math::abs(Izz))) // TODO: sthg else than 9.e-3 ?
+	Matrix3r matI, diagI;
+	matI << Ixx, Ixy, Ixz, Ixy, Iyy, Iyz, Ixz, Iyz, Izz; // full inertia matrix
+	diagI << Ixx, 0, 0, 0, Iyy, 0, 0, 0, Izz;            // just its diagonal components
+	Real ratio((matI - diagI).norm() / diagI.norm());    // how much non-diagonal matI is
+	if (ratio > 5.e-3) // 0.005 is a convenient value for jduriez .stl data and usual grids, while being probably small enough
 		LOG_ERROR(
-		        "Incorrect LevelSet description: local frame is non_inertial with a out-of-diagonal / diagonal terms ratio = "
-		        << (math::abs(Ixy) + math::abs(Ixz) + math::abs(Iyz)) / (math::abs(Ixx) + math::abs(Iyy) + math::abs(Izz)));
-	inertia = Vector3r(Ixx, Iyy, Izz);
+		        "Incorrect LevelSet input: local frame is non-inertial. Indeed, Ixx = "
+		        << Ixx << " ; Iyy = " << Iyy << " ; Izz = " << Izz << " ; Ixy = " << Ixy << " ; Ixz = " << Ixz << " ; Iyz = " << Iyz
+		        << " for inertia matrix I, making for a " << ratio << " non-diagonality ratio.");
+	inertia    = Vector3r(Ixx, Iyy, Izz);
+	lengthChar = twoD
+	        ? sqrt(volume / lsGrid->spacing)
+	        : cbrt(volume); // measuring lengthChar here (even if surfNodes already exist and won't be recomputed below) to allow a user to satisfactory call for a rayTrace even after a O.save / O.load
 	if (!surfNodes
 	             .size()) { // 0 boundary nodes as of now. Condition could be false after save/load, where we do not need to duplicate the nodes. Other choice to avoid this test would be to save everything else that's computed by init(), eg center, ..
-		lengthChar = twoD ? sqrt(volume / lsGrid->spacing) : cbrt(volume); // for the node location tolerance
 		initSurfNodes();
 		sphericity = maxRad / minRad;
-	} // note that sphericity is always saved (but maxRad, minRad not)
+	} // note that sphericity is always saved (but maxRad, minRad are not and are meaningfull only after initSurfNodes())
 	initDone = true;
 }
 
@@ -415,5 +447,71 @@ Vector3r LevelSet::getInertia()
 	return inertia;
 }
 
+Real LevelSet::getSurface() const
+{
+	Real nbrAngles(sqrt(surfNodes.size() - 2));
+	if (nodesPath != 1 or nbrAngles != int(nbrAngles)) {
+		LOG_ERROR(
+		        "Impossible to compute surface with nodesPath = " << nodesPath << " (1 expected) and " << surfNodes.size()
+		                                                          << " surface nodes (squared integer + 2 expected). Returning -1");
+		return -1.;
+	}
+	Real dtheta(Mathr::PI / (nbrAngles + 1)), dphi(2 * Mathr::PI / nbrAngles);
+	Real surf(0.);
+	for (unsigned int idx = 2; idx < surfNodes.size(); idx++) {
+		Vector3r spher = ShopLS::cart2spher(surfNodes[idx]); // (r,theta,phi) spherical coordinates
+		surf += pow(spher[0], 2) * sin(spher[1]) * dtheta * dphi;
+	}
+	return surf;
+}
+void LevelSet::computeMarchingCubes()
+{
+	// Clear possible existing marching cube data
+	// (might matter later if the level set grid changes size)
+	marchingCubesData.triangles.clear();
+	marchingCubesData.normals.clear();
+
+	// Compute the Marching Cubes triangulation
+	MarchingCube mc;
+	Vector3i     gpPerAxis = lsGrid->nGP;
+	int          nGPx(gpPerAxis[0]), nGPy(gpPerAxis[1]), nGPz(gpPerAxis[2]);
+	mc.init(nGPx, nGPy, nGPz, lsGrid->min, lsGrid->max());
+	mc.computeTriangulation(distField, 0);
+
+	// Removing garbage values
+	vector<Vector3r> obtTriangles(mc.getTriangles());
+	obtTriangles.resize(3 * mc.getNbTriangles());
+	vector<Vector3r> obtNormals(mc.getNormals());
+	obtNormals.resize(3 * mc.getNbTriangles());
+
+	// Store newly computed marching cube data
+	marchingCubesData.triangles   = obtTriangles;
+	marchingCubesData.normals     = obtNormals;
+	marchingCubesData.nbTriangles = mc.getNbTriangles();
+
+	initDoneMarchingCubes = true;
+}
+
+vector<Vector3r> LevelSet::getMarchingCubeTriangles()
+{
+	if (!initDone) init();
+	if (!initDoneMarchingCubes) computeMarchingCubes();
+	return marchingCubesData.triangles;
+}
+
+vector<Vector3r> LevelSet::getMarchingCubeNormals()
+{
+	if (!initDone) init();
+	if (!initDoneMarchingCubes) computeMarchingCubes();
+	return marchingCubesData.normals;
+}
+
+int LevelSet::getMarchingCubeNbTriangles()
+{
+	if (!initDone) init();
+	if (!initDoneMarchingCubes) computeMarchingCubes();
+	return marchingCubesData.nbTriangles;
+}
+
 } // namespace yade
 #endif //YADE_LS_DEM
