@@ -177,13 +177,15 @@ vector<vector<vector<Real>>> ShopLS::distIniSE(const Vector3r& radii, const Vect
 	return phiIni(1, radii, epsilons, clump, grid);
 }
 
-shared_ptr<LevelSet> ShopLS::lsSimpleShape(int shape, const AlignedBox3r& aabb, const Real& step, const Vector2r& epsilons, shared_ptr<Clump> clump)
+shared_ptr<LevelSet>
+ShopLS::lsSimpleShape(int shape, const AlignedBox3r& aabb, const Real& step, const Real& smearCoeff, const Vector2r& epsilons, shared_ptr<Clump> clump)
 {
 	Vector3r minBod(aabb.min()), maxBod(aabb.max()), dimAabb(maxBod - minBod);
 	if ((dimAabb[0] < 0) || (dimAabb[1] < 0) || (dimAabb[2] < 0)) LOG_ERROR("You specified negative extents for aabb, this is not expected.");
 
 	shared_ptr<LevelSet> lsShape(new LevelSet);
-	Vector3r             maxGrid,
+	lsShape->smearCoeff = smearCoeff;
+	Vector3r maxGrid,
 	        minGrid; // [minGrid,maxGrid] will be LevelSet->lsGrid. It may be different (bigger) than [minBod,maxBod] for the grid to go a little beyond the surface
 	                 // clang-format off
 	// ***** 1. We first define the grid (and twoD) depending upon the shape chosen *******
@@ -193,8 +195,10 @@ shared_ptr<LevelSet> ShopLS::lsSimpleShape(int shape, const AlignedBox3r& aabb,
 		minGrid       = -maxGrid;
 		lsShape->twoD = true;
 	} else if (shape <= 4) { // sphere, box, superellipsoid, clump of spherical particles, all combined
-		minGrid       = minBod - step * Vector3r::Ones();
-		maxGrid       = maxBod + step * Vector3r::Ones();
+		                 //		NB: pay attention to the following line, it has to enable the origin to belong to the grid (on all 3 axes)
+		int nIntX(int(ceil(maxBod[0] / step)) + 1), nIntY(int(ceil(maxBod[1] / step)) + 1), nIntZ(int(ceil(maxBod[2] / step)) + 1);
+		maxGrid       = Vector3r(nIntX * step, nIntY * step, nIntZ * step);
+		minGrid       = -maxGrid;
 		lsShape->twoD = false;
 	} else
 		LOG_FATAL("You asked for some shape value=" << shape << " which is not supported");
@@ -310,8 +314,7 @@ Vector3r ShopLS::grad_fioRose(Vector3r gp)
 	Vector3r grad_fio(1, -7.5 / r * cos(5 * theta) * sin(4 * phi), -6 / r * sin(5 * theta) / sin(theta) * cos(4 * phi));
 	return grad_fio;
 }
-shared_ptr<ScGeom>
-ShopLS::geomPtrForLaterRemoval(const State& rbp1, const State& rbp2, const shared_ptr<Interaction>& c)
+shared_ptr<ScGeom> ShopLS::geomPtrForLaterRemoval(const State& rbp1, const State& rbp2, const shared_ptr<Interaction>& c)
 {
 	// to use when we can not really compute anything, e.g. bodies lsGrid do not overlap anymore, but still need to have some geom data (while returning true as per general InteractionLoop workflow because it is an existing interaction. Otherwise we would need to update InteractionLoop itself to avoid LOG_WARN messages). Data mostly include an infinite tensile stretch to insure subsequent interaction removal (by Law2)
 	return ShopLS::geomPtr(
@@ -322,7 +325,8 @@ ShopLS::geomPtrForLaterRemoval(const State& rbp1, const State& rbp2, const share
 	        rbp1,
 	        rbp2,
 	        c,
-	        Vector3r::UnitX() /* inconsequential bullsh..*/);
+	        Vector3r::UnitX() /* inconsequential bullsh..*/,
+	        Vector3r::Zero() /* inconsequential bullsh..*/);
 }
 
 shared_ptr<ScGeom> ShopLS::geomPtr(
@@ -333,7 +337,8 @@ shared_ptr<ScGeom> ShopLS::geomPtr(
         const State&                   rbp1,
         const State&                   rbp2,
         const shared_ptr<Interaction>& c,
-        const Vector3r&                currentNormal)
+        const Vector3r&                currentNormal,
+        const Vector3r&                shift2)
 {
 	shared_ptr<ScGeom> geomPtr;
 	bool               isNew = !c->geom;
@@ -357,7 +362,7 @@ shared_ptr<ScGeom> ShopLS::geomPtr(
 	        c,
 	        currentNormal,
 	        isNew,
-	        Vector3r::Zero(),
+	        shift2,
 	        false); // the avoidGranularRatcheting=1 expression of relative velocity at contact does not make sense with radius1 and radius2 in all cases of LevelSet-sthg interaction (because the shapes are non-spherical): our present radius1+radius2 may have nothing in common with branch vector
 	// precompute will take care of
 	// * preparing the rotation of shearForce to the new tangent plane (done later, in Law2) defining these orthonormal_axis and twist_axis
