@@ -3,7 +3,12 @@
 #ifdef YADE_MPI
 
 #include "FoamCoupling.hpp"
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpragmas"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wcast-function-type"
 #include <mpi.h>
+#pragma GCC diagnostic pop
 
 #include <pkg/common/Box.hpp>
 #include <pkg/common/Facet.hpp>
@@ -24,9 +29,7 @@ YADE_PLUGIN((Bo1_FluidDomainBbox_Aabb));
 void Bo1_FluidDomainBbox_Aabb::go(const shared_ptr<Shape>& cm, shared_ptr<Bound>& bv, const Se3r&, const Body*)
 {
 	FluidDomainBbox* domain = static_cast<FluidDomainBbox*>(cm.get());
-	if (!bv) {
-		bv = shared_ptr<Bound>(new Aabb);
-	}
+	if (!bv) { bv = shared_ptr<Bound>(new Aabb); }
 	Aabb* aabb = static_cast<Aabb*>(bv.get());
 
 	aabb->min = scene->isPeriodic ? scene->cell->wrapPt(domain->minBound) : domain->minBound;
@@ -97,9 +100,9 @@ void FoamCoupling::eraseId(int bId)
 }
 
 
-int FoamCoupling::getNumBodies() { return bodyList.size(); }
+int FoamCoupling::getNumBodies() const { return bodyList.size(); }
 
-std::vector<int> FoamCoupling::getIdList() { return bodyList; }
+std::vector<int> FoamCoupling::getIdList() const { return bodyList; }
 
 void FoamCoupling::castParticle()
 {
@@ -158,8 +161,7 @@ void FoamCoupling::updateProcList()
 	for (unsigned int i = 0; i != bodyList.size(); ++i) {
 		int dummy_val = -5;
 		MPI_Allreduce(&dummy_val, &procList[i], 1, MPI_INT, MPI_MAX, MPI_COMM_WORLD);
-		if (procList[i] < 0)
-			LOG_WARN("particle id" << i << "not found in FOAM" << std::endl);
+		if (procList[i] < 0) LOG_WARN("particle id" << i << "not found in FOAM" << std::endl);
 	}
 }
 
@@ -219,7 +221,7 @@ void FoamCoupling::exchangeDeltaT()
 	dataExchangeInterval = (long int)((yadeDt < foamDeltaT) ? foamDeltaT / yadeDt : 1);
 }
 
-Real FoamCoupling::getViscousTimeScale()
+Real FoamCoupling::getViscousTimeScale() const
 {
 	//  Real hDeltaT = 0.0;
 	//  Real dummy = 1e9;
@@ -265,9 +267,9 @@ void FoamCoupling::getFluidDomainBbox()
 	//recv the grid minmax from fluid solver.
 
 	for (int rnk = 0; rnk != commSzdff; ++rnk) {
-		MPI_Status           status;
+		MPI_Status           status2;
 		std::vector<double>& buff = minMaxBuff[rnk];
-		MPI_Recv(&buff.front(), 6, MPI_DOUBLE, rnk + stride, TAG_GRID_BBOX, MPI_COMM_WORLD, &status);
+		MPI_Recv(&buff.front(), 6, MPI_DOUBLE, rnk + stride, TAG_GRID_BBOX, MPI_COMM_WORLD, &status2);
 	}
 
 	fluidDomains.resize(commSzdff);
@@ -328,9 +330,7 @@ void FoamCoupling::buildSharedIdsMap()
 			if (otherBody->getIsFluidDomainBbox()) {
 				const shared_ptr<FluidDomainBbox>& flbox = YADE_PTR_CAST<FluidDomainBbox>(otherBody->shape);
 				flbox->bIds.push_back(bodyId);
-				if (!flbox->hasIntersection) {
-					flbox->hasIntersection = true;
-				}
+				if (!flbox->hasIntersection) { flbox->hasIntersection = true; }
 				int indx = (flbox->bIds.size()) - 1;
 				testMap.insert(std::make_pair(
 				        otherId,
@@ -347,9 +347,7 @@ void FoamCoupling::buildSharedIdsMap()
 		const shared_ptr<Body>& flb = (*scene->bodies)[fluidId];
 		if (flb) {
 			const shared_ptr<FluidDomainBbox>& flBox = YADE_PTR_CAST<FluidDomainBbox>(flb->shape);
-			if (flBox->bIds.size() > 0) {
-				inCommunicationProc.push_back(std::make_pair(flBox->domainRank, flBox->bIds.size()));
-			}
+			if (flBox->bIds.size() > 0) { inCommunicationProc.push_back(std::make_pair(flBox->domainRank, flBox->bIds.size())); }
 		}
 	}
 }
@@ -374,9 +372,7 @@ void FoamCoupling::buildSharedIds()
 			} else {
 				otherId = intr->getId1();
 			}
-			if (ifFluidDomain(otherId)) {
-				fluidIds.push_back(otherId);
-			}
+			if (ifFluidDomain(otherId)) { fluidIds.push_back(otherId); }
 		}
 		if (fluidIds.size() > 1) {
 			sharedIds.push_back(std::make_pair(subD->ids[bodyId], fluidIds));
@@ -393,9 +389,7 @@ int FoamCoupling::ifSharedIdMap(const Body::id_t& testId)
 		return testId == elem.first;
 	});
 
-	if (it != sharedIdsMapIndx.end()) {
-		res = it - sharedIdsMapIndx.begin();
-	}
+	if (it != sharedIdsMapIndx.end()) { res = it - sharedIdsMapIndx.begin(); }
 	return res;
 }
 
@@ -413,9 +407,7 @@ bool FoamCoupling::ifFluidDomain(const Body::id_t& testId)
 
 void FoamCoupling::buildLocalIds()
 {
-	if (localRank == yadeMaster) {
-		return;
-	} // master has no bodies.
+	if (localRank == yadeMaster) { return; } // master has no bodies.
 	if (bodyList.size() == 0) {
 		LOG_ERROR("Ids for coupling has no been set, FAIL!");
 		return;
@@ -427,9 +419,7 @@ void FoamCoupling::buildLocalIds()
 	}
 	for (const auto& testId : bodyList) {
 		std::vector<Body::id_t>::iterator iter = std::find(subD->ids.begin(), subD->ids.end(), testId); // can subD have ids sorted?
-		if (iter != subD->ids.end()) {
-			localIds.push_back(*iter);
-		}
+		if (iter != subD->ids.end()) { localIds.push_back(*iter); }
 	}
 }
 
@@ -547,9 +537,9 @@ void FoamCoupling::verifyParticleDetection()
 	for (auto& it : verifyTracking) {
 		std::vector<int>& vt  = it.second;
 		int               rnk = it.first;
-		MPI_Status        status;
+		MPI_Status        status2;
 		int               buffSz = vt.size();
-		MPI_Recv(&vt.front(), buffSz, MPI_INT, rnk, TAG_SEARCH_RES, MPI_COMM_WORLD, &status);
+		MPI_Recv(&vt.front(), buffSz, MPI_INT, rnk, TAG_SEARCH_RES, MPI_COMM_WORLD, &status2);
 	}
 
 
@@ -590,8 +580,7 @@ void FoamCoupling::verifyParticleDetection()
 				const shared_ptr<FluidDomainBbox>& flbox = YADE_PTR_CAST<FluidDomainBbox>((*scene->bodies)[fdIndx.first]->shape);
 				for (const auto& vt : verifyTracking) {
 					if (vt.first == flbox->domainRank) {
-						if (vt.second[fdIndx.second] > 0)
-							found = true;
+						if (vt.second[fdIndx.second] > 0) found = true;
 					}
 				}
 			}
@@ -621,9 +610,9 @@ void FoamCoupling::getParticleForce()
 		std::vector<double>& tmpForce = recvForce.second;
 		int                  recvRank = recvForce.first;
 		int                  buffSz   = tmpForce.size();
-		MPI_Status           status;
+		MPI_Status           status2;
 		/* fluid procs having no particles will send 0 force, torque */
-		MPI_Recv(&tmpForce.front(), buffSz, MPI_DOUBLE, recvRank, TAG_FORCE, MPI_COMM_WORLD, &status);
+		MPI_Recv(&tmpForce.front(), buffSz, MPI_DOUBLE, recvRank, TAG_FORCE, MPI_COMM_WORLD, &status2);
 	}
 }
 
@@ -647,9 +636,7 @@ void FoamCoupling::resetFluidDomains()
 void FoamCoupling::setHydroForceParallel()
 {
 	// add the force
-	if (localRank == yadeMaster) {
-		return;
-	}
+	if (localRank == yadeMaster) { return; }
 	for (const auto& rf : hForce) {
 		int                                indx     = abs(rf.first - localCommSize);
 		const std::vector<double>&         forceVec = rf.second;
@@ -674,9 +661,9 @@ void FoamCoupling::exchangeDeltaTParallel()
 	// Recv foamdt  first and broadcast;
 
 	if (localRank == yadeMaster) {
-		MPI_Status status;
+		MPI_Status status2;
 		int        fluidMaster = stride;
-		MPI_Recv(&foamDeltaT, 1, MPI_DOUBLE, fluidMaster, TAG_FLUID_DT, MPI_COMM_WORLD, &status);
+		MPI_Recv(&foamDeltaT, 1, MPI_DOUBLE, fluidMaster, TAG_FLUID_DT, MPI_COMM_WORLD, &status2);
 	}
 
 	//bcast  the fluidDt to all yade_procs.
@@ -727,9 +714,7 @@ void FoamCoupling::runCouplingParallel()
 
 void FoamCoupling::action()
 {
-	if (!commSizeSet) {
-		getRank();
-	}
+	if (!commSizeSet) { getRank(); }
 
 	if (!couplingModeParallel) {
 		if (exchangeData()) {
@@ -752,8 +737,7 @@ bool FoamCoupling::exchangeData() { return scene->iter % dataExchangeInterval ==
 void FoamCoupling::killMPI()
 {
 	castTerminate();
-	if (!couplingModeParallel)
-		MPI_Finalize();
+	if (!couplingModeParallel) MPI_Finalize();
 }
 } // namespace yade
 
