@@ -6,18 +6,22 @@
 
 #include <lib/base/Logging.hpp>
 #include <lib/serialization/Serializable.hpp>
+#include <core/Aabb.hpp>
 #include <core/Body.hpp>
+#include <core/Dispatching.hpp>
 #include <core/GlobalEngine.hpp>
 #include <core/InteractionContainer.hpp>
 #include <core/Omega.hpp>
 #include <core/Scene.hpp>
 #include <core/Subdomain.hpp>
-#include <pkg/common/Aabb.hpp>
-#include <pkg/common/Dispatching.hpp>
 #include <pkg/common/Sphere.hpp>
-#include <mpi.h>
 #include <vector>
-
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpragmas"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wcast-function-type"
+#include <mpi.h>
+#pragma GCC diagnostic pop
 
 namespace yade { // Cannot have #include directive inside.
 
@@ -59,7 +63,7 @@ public:
 		void runCoupling(); 
 		bool exchangeData();
                 void castTerminate(); 
-		Real getViscousTimeScale();  // not fully implemented, piece of code left in foam.
+		Real getViscousTimeScale() const;  // not fully implemented, piece of code left in foam.
 		void getParticleForce();
 		virtual void verifyParticleDetection(); 
 		virtual void buildSharedIds(); 
@@ -74,8 +78,8 @@ public:
 		void exchangeDeltaTParallel(); 
 		void insertBodyId(int); 
 		void eraseId(int);
-		int getNumBodies(); 
-		std::vector<int> getIdList(); 
+		int getNumBodies() const;
+		std::vector<int> getIdList() const;
 		MPI_Comm *myComm_p; 
 		bool bodyListModified; 
     
@@ -89,9 +93,9 @@ public:
 			myComm_p = PyMPIComm_Get(py_obj);
 			if (myComm_p == NULL) LOG_ERROR("invalid COMM received from Python");
 		}
-		PyObject* getMyComm() {	return PyMPIComm_New(*myComm_p);}
+		PyObject* getMyComm() const {	return PyMPIComm_New(*myComm_p);}
 
-		virtual void action(); 
+		void action() override;
 		virtual ~FoamCoupling(){}; 
 		
 		std::vector<int> bodyList;  // 'global' all Ids across all procs which are in coupling. Used in serial mode  coupling. 
@@ -123,7 +127,7 @@ public:
 		int ifSharedIdMap(const Body::id_t& ); 
 		bool commSizeSet=false;
 		//bool couplingModeParallel = false; 
-		bool getCouplingMode(){return couplingModeParallel; }
+		bool getCouplingMode() const {return couplingModeParallel; }
 		void setCouplingMode(bool val){couplingModeParallel = val; } 
 		bool initDone; 
       
@@ -206,7 +210,7 @@ REGISTER_SERIALIZABLE(FluidDomainBbox);
 
 class Bo1_FluidDomainBbox_Aabb : public BoundFunctor {
 public:
-	void go(const shared_ptr<Shape>&, shared_ptr<Bound>&, const Se3r& se3, const Body*);
+	void go(const shared_ptr<Shape>&, shared_ptr<Bound>&, const Se3r& se3, const Body*) override;
 	FUNCTOR1D(FluidDomainBbox);
 	YADE_CLASS_BASE_DOC(Bo1_FluidDomainBbox_Aabb, BoundFunctor, "creates/updates an :yref:`Aabb` of a :yref:`FluidDomainBbox`.");
 };
