@@ -1,5 +1,6 @@
 // 2007 © Václav Šmilauer <eudoxos@arcig.cz>
 #include "Shop.hpp"
+#include <lib/base/LoggingUtils.hpp>
 #include <lib/high-precision/Constants.hpp>
 
 #include <core/Body.hpp>
@@ -224,7 +225,7 @@ py::tuple Shop::normalShearStressTensors(bool compressionPositive, bool splitNor
 	// *** Normal stress tensor split into two parts according to subnetworks of strong and weak forces (or other distinction if a threshold value for the force is assigned) ***/
 	Real     Fmean(0);
 	Matrix3r f, fs, fw;
-	fabricTensor(Fmean, f, fs, fw); // 0,false,NaN for cutoff, split and thresholdForce as default arguments
+	fabricTensor(Fmean, f, fs, fw); // 0,false,NaN,empty vector for cutoff, split, thresholdForce and extrema as default arguments
 	Matrix3r sigNStrong(Matrix3r::Zero()), sigNWeak(Matrix3r::Zero());
 	FOREACH(const shared_ptr<Interaction>& I, *scene->interactions)
 	{
@@ -267,16 +268,31 @@ py::tuple Shop::normalShearStressTensors(bool compressionPositive, bool splitNor
 
 /* Return the fabric tensor as according to [Satake1982]. */
 /* as side-effect, set Gl1_NormShear::strongWeakThresholdForce */
-void Shop::fabricTensor(Real& Fmean, Matrix3r& fabric, Matrix3r& fabricStrong, Matrix3r& fabricWeak, Real cutoff, bool splitTensor, Real thresholdForce)
+void Shop::fabricTensor(
+        Real&            Fmean,
+        Matrix3r&        fabric,
+        Matrix3r&        fabricStrong,
+        Matrix3r&        fabricWeak,
+        Real             cutoff,
+        bool             splitTensor,
+        Real             thresholdForce,
+        vector<Vector3r> extrema)
 {
 	Scene* scene = Omega::instance().getScene().get();
 
 	// *** Fabric tensor ***/
-	fabric           = Matrix3r::Zero();
-	int        count = 0; // number of interactions
-	const auto aabb  = Shop::aabbExtrema(cutoff);
-	Vector3r   bbMin = aabb.first, bbMax = aabb.second;
-	Vector3r   cp;
+	fabric         = Matrix3r::Zero();
+	int      count = 0; // number of interactions
+	Vector3r bbMin, bbMax;
+	if (!extrema.size()) {
+		const auto aabb = Shop::aabbExtrema(cutoff);
+		bbMin           = aabb.first;
+		bbMax           = aabb.second;
+	} else {
+		bbMin = extrema[0];
+		bbMax = extrema[1];
+	}
+	Vector3r cp;
 
 	Fmean = 0; // initialize average contact force for split = 1 fabric measurements
 	// interactions loop to compute the fabric tensor returned when split = 0, and also measures average force for subsequent computations for split = 1:
@@ -363,11 +379,11 @@ void Shop::fabricTensor(Real& Fmean, Matrix3r& fabric, Matrix3r& fabricStrong, M
 	}
 }
 
-py::tuple Shop::fabricTensor(Real cutoff, bool splitTensor, Real thresholdForce)
+py::tuple Shop::fabricTensor(Real cutoff, bool splitTensor, Real thresholdForce, vector<Vector3r> extrema)
 {
 	Real     Fmean;
 	Matrix3r fabric, fabricStrong, fabricWeak;
-	fabricTensor(Fmean, fabric, fabricStrong, fabricWeak, cutoff, splitTensor, thresholdForce);
+	fabricTensor(Fmean, fabric, fabricStrong, fabricWeak, cutoff, splitTensor, thresholdForce, extrema);
 	// returns fabric tensor or alternatively the two distinct contributions according to strong and weak subnetworks (or, if thresholdForce is specified, the distinction is made according to that value and not the mean one)
 	if (!splitTensor) {
 		return py::make_tuple(fabric);
@@ -382,7 +398,9 @@ Matrix3r Shop::getStress(Real volume)
 	Real   volumeNonPeri = 0;
 	if (volume == 0 && !scene->isPeriodic) {
 		const auto extrema = Shop::aabbExtrema();
-		volumeNonPeri      = (extrema.second[0] - extrema.first[0]) * (extrema.second[1] - extrema.first[1]) * (extrema.second[2] - extrema.first[2]);
+		LOG_ONCE_WARN("getStress used with default volume tend to underestimate the stress due to overlaps on the boundaries, passing actual volume "
+		              "could be more safe.")
+		volumeNonPeri = (extrema.second[0] - extrema.first[0]) * (extrema.second[1] - extrema.first[1]) * (extrema.second[2] - extrema.first[2]);
 	}
 	if (volume == 0) volume = scene->isPeriodic ? scene->cell->hSize.determinant() : volumeNonPeri;
 	Matrix3r   stressTensor = Matrix3r::Zero();
@@ -392,6 +410,9 @@ Matrix3r Shop::getStress(Real volume)
 		if (!I->isReal()) continue;
 		shared_ptr<Body> b1 = Body::byId(I->getId1(), scene);
 		shared_ptr<Body> b2 = Body::byId(I->getId2(), scene);
+		if (b1->isClumpMember()) b1 = Body::byId(b1->clumpId, scene);
+		if (b2->isClumpMember()) b2 = Body::byId(b2->clumpId, scene);
+
 		if (b1->shape->getClassIndex() == GridNode::getClassIndexStatic())
 			continue; //no need to check b2 because a GridNode can only be in interaction with an oher GridNode.
 		NormShearPhys* nsi    = YADE_CAST<NormShearPhys*>(I->phys.get());
