@@ -439,7 +439,10 @@ Real Shop__getVoxelPorosity(int resolution, Vector3r start, Vector3r end)
 }
 
 //Matrix3r Shop__stressTensorOfPeriodicCell(bool smallStrains=false){return Shop::stressTensorOfPeriodicCell(smallStrains);}
-py::tuple Shop__fabricTensor(Real cutoff, bool splitTensor, Real thresholdForce) { return Shop::fabricTensor(cutoff, splitTensor, thresholdForce); }
+py::tuple Shop__fabricTensor(Real cutoff, bool splitTensor, Real thresholdForce, vector<Vector3r> extrema)
+{
+	return Shop::fabricTensor(cutoff, splitTensor, thresholdForce, extrema);
+}
 py::tuple Shop__normalShearStressTensors(bool compressionPositive, bool splitNormalTensor, Real thresholdForce)
 {
 	return Shop::normalShearStressTensors(compressionPositive, splitNormalTensor, thresholdForce);
@@ -716,14 +719,7 @@ try {
 	py::def("wireNoSpheres", wireNoSpheres, "Set :yref:`Shape::wire` to True on non-spherical bodies (:yref:`Facets<Facet>`, :yref:`Walls<Wall>`).");
 	py::def("flipCell",
 	        &Shop::flipCell,
-	        (py::arg("flip") = Matrix3r(Matrix3r::Zero())),
-	        "Flip periodic cell so that angles between $R^3$ axes and transformed axes are as small as possible, using the two following facts:"
-	        "1. repeating in $R^3$ space the corners of a periodic cell defines a regular grid; 2. two cells leading through this process to a unique grid "
-	        "are "
-	        "equivalent and can be flipped one over another. Flipping necessitates adjustment of :yref:`Interaction.cellDist` for interactions that cross "
-	        "the boundary and didn't before (or vice versa), and re-initialization of collider. The *flip* argument can be used to specify desired flip: "
-	        "integers, each column for one axis; if zero matrix, best fit (minimizing the angles) is computed automatically.\n\nIn c++, this function is "
-	        "accessible as ``Shop::flipCell``.");
+	        "utils.flipCell is deprecated, use :yref:`O.cell.flipCell<Cell::flipCell>` or :yref:`O.cell.flipFlippable<Cell::flipFlippable>`");
 	py::def("getViscoelasticFromSpheresInteraction",
 	        getViscoelasticFromSpheresInteraction,
 	        (py::arg("tc"), py::arg("en"), py::arg("es")),
@@ -747,13 +743,15 @@ try {
 	        "stress tensor can be split (e.g. a zero value would make distinction between tensile and compressive forces).");
 	py::def("fabricTensor",
 	        Shop__fabricTensor,
-	        (py::args("cutoff") = 0.0, py::args("splitTensor") = false, py::args("thresholdForce") = NaN),
+	        (py::args("cutoff") = 0.0, py::args("splitTensor") = false, py::args("thresholdForce") = NaN, py::args("extrema") = py::list()),
 	        "Computes the fabric tensor $F_{ij}=\\frac{1}{n_c}\\sum_c n_i n_j$ [Satake1982]_, for all interactions $c$.\n\n:param Real cutoff: intended to "
 	        "disregard boundary effects: to define in [0;1] to focus on the interactions located in the centered inner (1-cutoff)^3*$V$ part of the "
 	        "spherical packing $V$.\n\n:param bool splitTensor: split the fabric tensor into two parts related to the strong (greatest compressive normal "
 	        "forces) and weak contact forces respectively.\n\n:param Real thresholdForce: if the fabric tensor is split into two parts, a threshold value "
 	        "can be specified otherwise the mean contact force is considered by default. Use negative signed values for compressive states. To note that "
-	        "this value could be set to zero if one wanted to make distinction between compressive and tensile forces.");
+	        "this value could be set to zero if one wanted to make distinction between compressive and tensile forces.\n\n:param list extrema: defines "
+	        "through a two-Vector3-list (min,max) an axis aligned box that restricts the interactions to consider. A value has to be given for the "
+	        "function to be effective with non-spherical particles.");
 	py::def("bodyStressTensors",
 	        Shop__getStressLWForEachBody,
 	        // FIXME: use R"""(raw text)""" here, like exaplained in https://yade-dem.org/doc/prog.html#sphinx-documentation and used in py/_libVersions.cpp
@@ -937,15 +935,16 @@ try {
 		"Converts spherical coordinates to cartesian ones.\n\n:param Vector3 vec: the $(r,\\theta,\\phi)$ spherical coordinates, see cart2spher function for conventions\n:return: a $(x,y,z)$ Vector3 of cartesian coordinates");
 	py::def("lsSimpleShape",
 		ShopLS::lsSimpleShape,
-		(py::arg("shape"),py::arg("aabb"),py::arg("step")=0.1,py::arg("epsilons")=Vector2r(Vector2r::Zero()),py::arg("clump")=boost::make_shared<Clump>()), // Vector*r(Vector*r::Zero()) is actually necessary for to-Python conversion to work (and YADE to start)
+		(py::arg("shape"),py::arg("aabb"),py::arg("step")=0.1,py::arg("smearCoeff")=1.5,py::arg("epsilons")=Vector2r(Vector2r::Zero()),py::arg("clump")=boost::make_shared<Clump>()), // Vector*r(Vector*r::Zero()) is actually necessary for to-Python conversion to work (and YADE to start)
 		R"""(Creates a LevelSet shape among pre-defined ones. Not intended to be used directly, see levelSetBody() instead.
 
 :param int shape: a shape index among supported choices
 :param AlignedBox3 aabb: the axis-aligned surrounding box of the body
 :param Real step: the LevelSet grid step size
+:param Real smearCoeff: passed to LevelSet.smearCoeff
 :param Vector2 epsilons: the epsilon exponents in case *shape* = 3 (superellipsoid)
 :param Clump clump: the Clump instance to mimick in case *shape* = 4
-:return: a list (of list of list) corresponding to LevelSet.distField.)""");
+:return: a LevelSet instance.)""");
  // NB: the rest of the code makes a mixed use of py::arg and py::args, Boost doc does not really help for this https://www.boost.org/doc/libs/1_67_0/libs/python/doc/html/reference/function_invocation_and_creation.html#function_invocation_and_creation.boost_python_args_hpp, see /usr/include/boost/python/args.hpp if you wish...
 //	NB for the two following nGP: see overloading comments in ShopLS.hpp.
 	py::def("nGP",
