@@ -10,9 +10,9 @@
 #include <pkg/common/Sphere.hpp>
 #include <pkg/dem/DemXDofGeom.hpp>
 #include <pkg/dem/ScGeom.hpp>
-#include <preprocessing/dem/Shop.hpp>
 #include <pkg/dem/Tetra.hpp>
 #include <pkg/dem/ViscoelasticPM.hpp>
+#include <preprocessing/dem/Shop.hpp>
 #ifdef YADE_MPI
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wpragmas"
@@ -158,7 +158,7 @@ Real Shop__getPorosity(Real volume = -1);
 Real Shop__getVoxelPorosity(int resolution = 200, Vector3r start = Vector3r(0, 0, 0), Vector3r end = Vector3r(0, 0, 0));
 
 //Matrix3r Shop__stressTensorOfPeriodicCell(bool smallStrains=false){return Shop::stressTensorOfPeriodicCell(smallStrains);}
-py::tuple Shop__fabricTensor(Real cutoff = 0.0, bool splitTensor = false, Real thresholdForce = NaN);
+py::tuple Shop__fabricTensor(Real cutoff = 0.0, bool splitTensor = false, Real thresholdForce = NaN, vector<Vector3r> extrema = vector<Vector3r>());
 py::tuple Shop__normalShearStressTensors(bool compressionPositive = false, bool splitNormalTensor = false, Real thresholdForce = NaN);
 
 py::list Shop__getStressLWForEachBody();
