@@ -49,8 +49,8 @@ public:
 };
 
 struct PredicateWrap : Predicate, py::wrapper<Predicate> {
-	bool      operator()(const Vector3r& pt, Real pad = 0.) const { return this->get_override("__call__")(pt, pad); }
-	py::tuple aabb() const { return this->get_override("aabb")(); }
+	bool      operator()(const Vector3r& pt, Real pad = 0.) const override { return this->get_override("__call__")(pt, pad); }
+	py::tuple aabb() const override { return this->get_override("aabb")(); }
 };
 
 /*********************************************************************************
@@ -80,8 +80,8 @@ public:
 	        : PredicateBoolean(_A, _B)
 	{
 	}
-	virtual bool      operator()(const Vector3r& pt, Real pad) const { return obj2pred(A)(pt, pad) || obj2pred(B)(pt, pad); }
-	virtual py::tuple aabb() const
+	bool      operator()(const Vector3r& pt, Real pad) const override { return obj2pred(A)(pt, pad) || obj2pred(B)(pt, pad); }
+	py::tuple aabb() const override
 	{
 		Vector3r minA, maxA, minB, maxB;
 		ttuple2vvec(obj2pred(A).aabb(), minA, maxA);
@@ -97,8 +97,8 @@ public:
 	        : PredicateBoolean(_A, _B)
 	{
 	}
-	virtual bool      operator()(const Vector3r& pt, Real pad) const { return obj2pred(A)(pt, pad) && obj2pred(B)(pt, pad); }
-	virtual py::tuple aabb() const
+	bool      operator()(const Vector3r& pt, Real pad) const override { return obj2pred(A)(pt, pad) && obj2pred(B)(pt, pad); }
+	py::tuple aabb() const override
 	{
 		Vector3r minA, maxA, minB, maxB;
 		ttuple2vvec(obj2pred(A).aabb(), minA, maxA);
@@ -114,8 +114,8 @@ public:
 	        : PredicateBoolean(_A, _B)
 	{
 	}
-	virtual bool      operator()(const Vector3r& pt, Real pad) const { return obj2pred(A)(pt, pad) && !obj2pred(B)(pt, -pad); }
-	virtual py::tuple aabb() const { return obj2pred(A).aabb(); }
+	bool      operator()(const Vector3r& pt, Real pad) const override { return obj2pred(A)(pt, pad) && !obj2pred(B)(pt, -pad); }
+	py::tuple aabb() const override { return obj2pred(A).aabb(); }
 };
 PredicateDifference makeDifference(const py::object& A, const py::object& B) { return PredicateDifference(A, B); }
 
@@ -125,12 +125,12 @@ public:
 	        : PredicateBoolean(_A, _B)
 	{
 	}
-	virtual bool operator()(const Vector3r& pt, Real pad) const
+	bool operator()(const Vector3r& pt, Real pad) const override
 	{
 		bool inA = obj2pred(A)(pt, pad), inB = obj2pred(B)(pt, pad);
 		return (inA && !inB) || (!inA && inB);
 	}
-	virtual py::tuple aabb() const
+	py::tuple aabb() const override
 	{
 		Vector3r minA, maxA, minB, maxB;
 		ttuple2vvec(obj2pred(A).aabb(), minA, maxA);
@@ -156,8 +156,8 @@ public:
 		center = _center;
 		radius = _radius;
 	}
-	virtual bool      operator()(const Vector3r& pt, Real pad = 0.) const { return ((pt - center).norm() <= radius - pad); }
-	virtual py::tuple aabb() const
+	bool      operator()(const Vector3r& pt, Real pad = 0.) const override { return ((pt - center).norm() <= radius - pad); }
+	py::tuple aabb() const override
 	{
 		return vvec2tuple(
 		        Vector3r(center[0] - radius, center[1] - radius, center[2] - radius),
@@ -175,12 +175,12 @@ public:
 	        , mx(_mx)
 	{
 	}
-	virtual bool operator()(const Vector3r& pt, Real pad = 0.) const
+	bool operator()(const Vector3r& pt, Real pad = 0.) const override
 	{
 		return mn[0] + pad <= pt[0] && mx[0] - pad >= pt[0] && mn[1] + pad <= pt[1] && mx[1] - pad >= pt[1] && mn[2] + pad <= pt[2]
 		        && mx[2] - pad >= pt[2];
 	}
-	virtual py::tuple aabb() const { return vvec2tuple(mn, mx); }
+	py::tuple aabb() const override { return vvec2tuple(mn, mx); }
 };
 
 class inParallelepiped : public Predicate {
@@ -213,14 +213,13 @@ public:
 			mx = mx.cwiseMax(vertices[i]);
 		}
 	}
-	virtual bool operator()(const Vector3r& pt, Real pad = 0.) const
+	bool operator()(const Vector3r& pt, Real pad = 0.) const override
 	{
 		for (int i = 0; i < 6; i++)
-			if ((pt - pts[i]).dot(n[i]) > -pad)
-				return false;
+			if ((pt - pts[i]).dot(n[i]) > -pad) return false;
 		return true;
 	}
-	virtual py::tuple aabb() const { return vvec2tuple(mn, mx); }
+	py::tuple aabb() const override { return vvec2tuple(mn, mx); }
 };
 
 /*! Arbitrarily oriented cylinder predicate */
@@ -237,17 +236,15 @@ public:
 		radius = _radius;
 		ht     = c12.norm();
 	}
-	bool operator()(const Vector3r& pt, Real pad = 0.) const
+	bool operator()(const Vector3r& pt, Real pad = 0.) const override
 	{
-		Real u = (pt.dot(c12) - c1.dot(c12)) / (ht * ht); // normalized coordinate along the c1--c2 axis
-		if ((u * ht < 0 + pad) || (u * ht > ht - pad))
-			return false; // out of cylinder along the axis
+		Real u = (pt.dot(c12) - c1.dot(c12)) / (ht * ht);            // normalized coordinate along the c1--c2 axis
+		if ((u * ht < 0 + pad) || (u * ht > ht - pad)) return false; // out of cylinder along the axis
 		Real axisDist = ((pt - c1).cross(pt - c2)).norm() / ht;
-		if (axisDist > radius - pad)
-			return false;
+		if (axisDist > radius - pad) return false;
 		return true;
 	}
-	py::tuple aabb() const
+	py::tuple aabb() const override
 	{
 		// see http://www.gamedev.net/community/forums/topic.asp?topic_id=338522&forum_id=20&gforum_id=0 for the algorithm
 		const Vector3r& A(c1);
@@ -282,19 +279,17 @@ public:
 		c         = ht / (2 * uMax);
 	}
 	// WARN: this is not accurate, since padding is taken as perpendicular to the axis, not the the surface
-	bool operator()(const Vector3r& pt, Real pad = 0.) const
+	bool operator()(const Vector3r& pt, Real pad = 0.) const override
 	{
-		Real v = (pt.dot(c12) - c1.dot(c12)) / (ht * ht); // normalized coordinate along the c1--c2 axis
-		if ((v * ht < 0 + pad) || (v * ht > ht - pad))
-			return false;                // out of cylinder along the axis
-		Real u        = (v - .5) * ht / c;   // u from the wolfram parametrization; u is 0 in the center
-		Real rHere    = a * sqrt(1 + u * u); // pad is taken perpendicular to the axis, not to the surface (inaccurate)
+		Real v = (pt.dot(c12) - c1.dot(c12)) / (ht * ht);            // normalized coordinate along the c1--c2 axis
+		if ((v * ht < 0 + pad) || (v * ht > ht - pad)) return false; // out of cylinder along the axis
+		Real u        = (v - .5) * ht / c;                           // u from the wolfram parametrization; u is 0 in the center
+		Real rHere    = a * sqrt(1 + u * u);                         // pad is taken perpendicular to the axis, not to the surface (inaccurate)
 		Real axisDist = ((pt - c1).cross(pt - c2)).norm() / ht;
-		if (axisDist > rHere - pad)
-			return false;
+		if (axisDist > rHere - pad) return false;
 		return true;
 	}
-	py::tuple aabb() const
+	py::tuple aabb() const override
 	{
 		// the lazy way
 		return inCylinder(c1, c2, R).aabb();
@@ -311,7 +306,7 @@ public:
 		c   = _c;
 		abc = _abc;
 	}
-	bool operator()(const Vector3r& pt, Real pad = 0.) const
+	bool operator()(const Vector3r& pt, Real pad = 0.) const override
 	{
 		//Define the ellipsoid X-coordinate of given Y and Z
 		Real x = sqrt((1 - pow((pt[1] - c[1]), 2) / ((abc[1] - pad) * (abc[1] - pad)) - pow((pt[2] - c[2]), 2) / ((abc[2] - pad) * (abc[2] - pad)))
@@ -319,12 +314,11 @@ public:
 		        + c[0];
 		Vector3r edgeEllipsoid(x, pt[1], pt[2]); // create a vector of these 3 coordinates
 		//check whether given coordinates lie inside ellipsoid or not
-		if ((pt - c).norm() <= (edgeEllipsoid - c).norm())
-			return true;
+		if ((pt - c).norm() <= (edgeEllipsoid - c).norm()) return true;
 		else
 			return false;
 	}
-	py::tuple aabb() const
+	py::tuple aabb() const override
 	{
 		const Vector3r& center(c);
 		const Vector3r& ABC(abc);
@@ -374,27 +368,21 @@ public:
 		aperture = _aperture;
 		// LOG_DEBUG("edge="<<edge<<", normal="<<normal<<", inside="<<inside<<", aperture="<<aperture);
 	}
-	bool operator()(const Vector3r& pt, Real pad = 0.) const
+	bool operator()(const Vector3r& pt, Real pad = 0.) const override
 	{
 		Real distUp = normal.dot(pt - c) - aperture / 2, distDown = -normal.dot(pt - c) - aperture / 2, distInPlane = -inside.dot(pt - c);
 		// LOG_DEBUG("pt="<<pt<<", distUp="<<distUp<<", distDown="<<distDown<<", distInPlane="<<distInPlane);
-		if (distInPlane >= pad)
-			return true;
-		if (distUp >= pad)
-			return true;
-		if (distDown >= pad)
-			return true;
-		if (distInPlane < 0)
-			return false;
-		if (distUp > 0)
-			return sqrt(pow(distInPlane, 2) + pow(distUp, 2)) >= pad;
-		if (distDown > 0)
-			return sqrt(pow(distInPlane, 2) + pow(distUp, 2)) >= pad;
+		if (distInPlane >= pad) return true;
+		if (distUp >= pad) return true;
+		if (distDown >= pad) return true;
+		if (distInPlane < 0) return false;
+		if (distUp > 0) return sqrt(pow(distInPlane, 2) + pow(distUp, 2)) >= pad;
+		if (distDown > 0) return sqrt(pow(distInPlane, 2) + pow(distUp, 2)) >= pad;
 		// between both notch planes, closer to the edge than pad (distInPlane<pad)
 		return false;
 	}
 	// This predicate is not bounded, return infinities
-	py::tuple aabb() const
+	py::tuple aabb() const override
 	{
 		Real inf = std::numeric_limits<Real>::infinity();
 		return vvec2tuple(Vector3r(-inf, -inf, -inf), Vector3r(inf, inf, inf));
@@ -443,17 +431,14 @@ public:
 	        , noPad(_noPad)
 	        , noPadWarned(false)
 	{
-		if (!pygts_surface_check(_surf.ptr()))
-			throw std::invalid_argument("Ctor must receive a gts.Surface() instance.");
+		if (!pygts_surface_check(_surf.ptr())) throw std::invalid_argument("Ctor must receive a gts.Surface() instance.");
 		surf = PYGTS_SURFACE_AS_GTS_SURFACE(PYGTS_SURFACE(_surf.ptr()));
-		if (!gts_surface_is_closed(surf))
-			throw std::invalid_argument("Surface is not closed.");
+		if (!gts_surface_is_closed(surf)) throw std::invalid_argument("Surface is not closed.");
 		is_open = gts_surface_volume(surf) < 0.;
-		if ((tree = gts_bb_tree_surface(surf)) == NULL)
-			throw std::runtime_error("Could not create GTree.");
+		if ((tree = gts_bb_tree_surface(surf)) == NULL) throw std::runtime_error("Could not create GTree.");
 	}
 	~inGtsSurface() { g_node_destroy(tree); }
-	py::tuple aabb() const
+	py::tuple aabb() const override
 	{
 		Real                          inf = std::numeric_limits<Real>::infinity();
 		std::pair<Vector3r, Vector3r> bb;
@@ -474,11 +459,10 @@ public:
 		gp.z = static_cast<gdouble>(pt[2]);
 		return (bool)gts_point_is_inside_surface(&gp, tree, is_open);
 	}
-	bool operator()(const Vector3r& pt, Real pad = 0.) const
+	bool operator()(const Vector3r& pt, Real pad = 0.) const override
 	{
 		if (noPad) {
-			if (pad != 0. && noPadWarned)
-				LOG_WARN("inGtsSurface constructed with noPad; requested non-zero pad set to zero.");
+			if (pad != 0. && noPadWarned) LOG_WARN("inGtsSurface constructed with noPad; requested non-zero pad set to zero.");
 			return ptCheck(pt);
 		}
 		return ptCheck(pt) && ptCheck(pt - Vector3r(pad, 0, 0)) && ptCheck(pt + Vector3r(pad, 0, 0)) && ptCheck(pt - Vector3r(0, pad, 0))
